<?php

if( !function_exists( 'flat_commerce_bottom_section' ) ) :
/**
* Add Featured content.
*
* @uses action hook flat_commerce_before_content.
*
* @since Flat Commerce Pro 1.0
*/
function flat_commerce_bottom_section() {
    global $wp_query, $post;

    $page_id        = get_queried_object_id();
    $options        = flat_commerce_get_theme_options();

    $enableslider   = $options['bottom_section_enable_option'];

    $content_type  = $options['bottom_section_content_type'];
    $design_type  = $options['bottom_section_design_option'];

    $flat_commerce_bottom_section = '';

    // Front page displays in Reading Settings
    $page_on_front  = get_option( 'page_on_front' ) ;
    $page_for_posts = get_option( 'page_for_posts' );

    if ( $enableslider == 'entire-site' || ( ( $page_id == $page_on_front && $page_id > 0 ) && $enableslider == 'homepage' ) ) {
       if ( ( !$flat_commerce_bottom_section = get_transient( 'flat_commerce_bottom_section' ) ) ) {
            echo '<!-- refreshing about us section -->';
            $flat_commerce_bottom_social_media = '';
            if ( $options['bottom_section_social_media'] ) {
                $social_icon_num = $options['bottom_section_social_media_number'];
                $flat_commerce_bottom_social_media .=
                '<div class="social-icon">
                    <ul>';
                    for ( $i=1; $i <= $social_icon_num; $i++ ) {
                        if ( !empty( $options['bottom_section_social_media_icon'.$i] ) ) {
                            $flat_commerce_bottom_social_media .='<li><a href="';

                            if ( !empty( $options['bottom_section_social_media_url'.$i] ) ) {
                                $flat_commerce_bottom_social_media .= esc_url( $options['bottom_section_social_media_url'.$i] );
                            }

                            $flat_commerce_bottom_social_media .= '" target="_blank"><span class="genericon genericon-'.esc_attr( $options['bottom_section_social_media_icon'.$i] ).'"></span></a></li>';
                        }
                    }
                    '</ul>
                </div><!-- .social-icon -->';
            }

            if ( 'design-1' === $design_type ) {
                $flat_commerce_bottom_section =
                '<section id="bottom-section">
                    <div class="container">
                        <div class="row">
                            <div class="col col-2-of-3 col-centered">
                                <div class="bottom-section-wrapper">';

                                    if ( $content_type == 'custom' ) {
                                        $flat_commerce_bottom_section .= flat_commerce_bottom_section_custom_content( $options );
                                    } elseif ( $content_type == 'page' ) {
                                        $flat_commerce_bottom_section .= flat_commerce_bottom_section_page_content( $options );
                                    }
                                '</div><!-- .bottom-section-wrapper -->';
                            $flat_commerce_bottom_section .= $flat_commerce_bottom_social_media . '</div><!-- .col -->
                        </div><!-- .row -->
                    </div><!-- .container -->
                </section><!-- #bottom-section -->';
            } elseif ( 'design-2' === $design_type ) {
                // Bottom section background
                $bottom_section_image_url = $options[ 'bottom_section_bg_image' ];
                if ( ! empty( $bottom_section_image_url ) ) {
                    $image_url = $bottom_section_image_url;
                    $class = 'has-post-thumbnail';
                } else {
                    $class = 'no-post-thumbnail';
                    $image_url = '';
                }

                $flat_commerce_bottom_section =
                '<section id="about-us" class="clear">
                    <div class="container">
                        <div class="page-section ">
                            <article class="'.esc_attr( $class ).'"> ';
                                if ( ! empty( $image_url ) ) {
                                    $flat_commerce_bottom_section .= '<div class="featured-image">
                                        <img src="'.esc_url( $image_url ).'">
                                    </div>';
                                }
                                $flat_commerce_bottom_section .= '<div class="entry-summary">';

                                    if ( $content_type == 'custom' ) {
                                        $flat_commerce_bottom_section .= flat_commerce_bottom_section_custom_content( $options );
                                    } elseif ( $content_type == 'page' ) {
                                        $flat_commerce_bottom_section .= flat_commerce_bottom_section_page_content( $options );
                                    }
                                '</div><!-- .entry-summary -->
                            </article>';
                            $flat_commerce_bottom_section .= $flat_commerce_bottom_social_media . '
                    </div><!-- .page-section -->
                </div><!-- .container -->
            </section><!-- #about-us -->';
            }

            set_transient( 'flat_commerce_bottom_section', $flat_commerce_bottom_section, 86940 );
        }
        echo $flat_commerce_bottom_section;
    }
}
endif;
add_action( 'flat_commerce_after_content', 'flat_commerce_bottom_section', 20 );



if ( ! function_exists( 'flat_commerce_bottom_section_page_content' ) ) :
/**
 * This function to display bottom section page content
 *
 * @param $options: flat_commerce_theme_options from customizer
 *
 * @since Flat Commerce Pro 1.0
 */
function flat_commerce_bottom_section_page_content( $options ) {
    $page_id = ! empty ( $options['bottom_section_page'] ) ? $options['bottom_section_page'] : '';
    $page = get_post( $page_id );
    $bottom_section_page_content = '
        <header class="entry-header">
            <h2 class="entry-title">'.get_the_title( $page_id ).'</h2>
        </header><!-- .entry-header -->
        <div class="entry-content">
            <p>'.wp_kses_post( $page->post_content ).'</p>
        </div><!-- .entry-content -->';
        if ( $options['bottom_section_read_more_link']) {
            $bottom_section_page_content .= '<a href="'.esc_url( get_permalink( $page_id ) ).'" class="read-more">'.sanitize_text_field( $options['bottom_section_read_more_link_text'] ).'</a>';
        }

    return $bottom_section_page_content;
}
endif;


if ( ! function_exists( 'flat_commerce_bottom_section_custom_content' ) ) :
/**
 * This function to display bottom section page content
 *
 * @param $options: flat_commerce_theme_options from customizer
 *
 * @since Flat Commerce Pro 1.0
 */
function flat_commerce_bottom_section_custom_content( $options ) {
    $bottom_section_custom_content = '
        <header class="entry-header">
            <h2 class="entry-title">'.$options['bottom_section_title'].'</h2>
        </header><!-- .entry-header -->
        <div class="entry-content">
            <p>'.$options['bottom_section_sub_title'].'</p>
        </div><!-- .entry-content -->';
        if ( $options['bottom_section_read_more_link']) {
            $bottom_section_custom_content .= '<a href="'.esc_url( $options['bottom_section_read_more_link_to'] ).'" class="read-more">'.sanitize_text_field( $options['bottom_section_read_more_link_text'] ).'</a>';
        }

    return $bottom_section_custom_content;
}
endif;
