<?php
/**
 * Active callbacks for Theme Customizer Options
 *
 * @package Theme Palace
 * @subpackage Flat Commerce Pro
 * @since Flat Commerce Pro 1.0
 */

if ( ! defined( 'FLAT_COMMERCE_THEME_VERSION' ) ) {
	header( 'Status: 403 Forbidden' );
	header( 'HTTP/1.0 403 Forbidden' );
	exit();
}

if( ! function_exists( 'flat_commerce_is_slider_active' ) ) :
	/**
	* Return true if slider is active
	*
	* @since  Flat Commerce Pro 1.0
	*/
	function flat_commerce_is_slider_active( $control ) {
		global $wp_query;

		$page_id        = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
    	$page_on_front  = get_option('page_on_front') ;

		$enable         = $control->manager->get_setting( 'flat_commerce_theme_options[featured_slider_option]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected
		return ( $enable == 'entire-site' || ( ( $page_id == $page_on_front && $page_id > 0  ) && $enable == 'homepage' ) );
	}
endif;


if( ! function_exists( 'flat_commerce_is_demo_slider_inactive' ) ) :
	/**
	* Return true if demo slider is inactive
	*
	* @since  Flat Commerce Pro 1.0
	*/
	function flat_commerce_is_demo_slider_inactive( $control ) {
		global $wp_query;

		$page_id        = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
    	$page_on_front  = get_option('page_on_front') ;

		$enable         = $control->manager->get_setting( 'flat_commerce_theme_options[featured_slider_option]' )->value();

		$type           = $control->manager->get_setting( 'flat_commerce_theme_options[featured_slider_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and is not demo slider
		return ( ( $enable == 'entire-site' || ( ( $page_id == $page_on_front && $page_id > 0  ) && $enable == 'homepage' ) ) && !( 'demo-featured-slider' == $type ) );
	}
endif;


if( ! function_exists( 'flat_commerce_is_post_slider_active' ) ) :
	/**
	* Return true if page slider is active
	*
	* @since  Flat Commerce Pro 1.0
	*/
	function flat_commerce_is_post_slider_active( $control ) {
		global $wp_query;

		$page_id        = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
    	$page_on_front  = get_option('page_on_front') ;

		$enable         = $control->manager->get_setting( 'flat_commerce_theme_options[featured_slider_option]' )->value();

		$type           = $control->manager->get_setting( 'flat_commerce_theme_options[featured_slider_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and page slider
		return ( ( $enable == 'entire-site' || ( ( $page_id == $page_on_front && $page_id > 0  ) && $enable == 'homepage' ) ) && ( 'featured-post-slider' == $type ) );
	}
endif;


if( ! function_exists( 'flat_commerce_is_page_slider_active' ) ) :
	/**
	* Return true if page slider is active
	*
	* @since  Flat Commerce Pro 1.0
	*/
	function flat_commerce_is_page_slider_active( $control ) {
		global $wp_query;

		$page_id        = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
    	$page_on_front  = get_option('page_on_front') ;

		$enable         = $control->manager->get_setting( 'flat_commerce_theme_options[featured_slider_option]' )->value();

		$type           = $control->manager->get_setting( 'flat_commerce_theme_options[featured_slider_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and page slider
		return ( ( $enable == 'entire-site' || ( ( $page_id == $page_on_front && $page_id > 0  ) && $enable == 'homepage' ) ) && ( 'featured-page-slider' == $type ) );
	}
endif;

if( ! function_exists( 'flat_commerce_is_featured_product_slider_active_' ) ) :
	/**
	* Return true if Woo category slider is active
	*
	* @since  Flat Commerce Pro 1.0
	*/
	function flat_commerce_is_featured_product_slider_active_( $control ) {
		global $wp_query;

		$page_id        = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
    	$page_on_front  = get_option('page_on_front') ;

		$enable         = $control->manager->get_setting( 'flat_commerce_theme_options[featured_slider_option]' )->value();

		$type           = $control->manager->get_setting( 'flat_commerce_theme_options[featured_slider_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and woo product
		return ( ( $enable == 'entire-site' || ( ( $page_id == $page_on_front && $page_id > 0  ) && $enable == 'homepage' ) ) && ( 'featured-woo-cat' == $type ) );
	}
endif;


if( ! function_exists( 'flat_commerce_is_category_slider_active' ) ) :
	/**
	* Return true if page slider is active
	*
	* @since  Flat Commerce Pro 1.0
	*/
	function flat_commerce_is_category_slider_active( $control ) {
		global $wp_query;

		$page_id        = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
    	$page_on_front  = get_option('page_on_front') ;

		$enable         = $control->manager->get_setting( 'flat_commerce_theme_options[featured_slider_option]' )->value();

		$type           = $control->manager->get_setting( 'flat_commerce_theme_options[featured_slider_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and page slider
		return ( ( $enable == 'entire-site' || ( ( $page_id == $page_on_front && $page_id > 0  ) && $enable == 'homepage' ) ) && ( 'featured-category-slider' == $type ) );
	}
endif;


if( ! function_exists( 'flat_commerce_is_image_slider_active' ) ) :
	/**
	* Return true if page slider is active
	*
	* @since  Flat Commerce Pro 1.0
	*/
	function flat_commerce_is_image_slider_active( $control ) {
		global $wp_query;

		$page_id        = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
    	$page_on_front  = get_option('page_on_front') ;

		$enable         = $control->manager->get_setting( 'flat_commerce_theme_options[featured_slider_option]' )->value();

		$type           = $control->manager->get_setting( 'flat_commerce_theme_options[featured_slider_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and page slider
		return ( ( $enable == 'entire-site' || ( ( $page_id == $page_on_front && $page_id > 0  ) && $enable == 'homepage' ) ) && ( 'featured-image-slider' == $type ) );
	}
endif;

if( ! function_exists( 'flat_commerce_is_post_and_page_slider_active' ) ) :
	/**
	* Return true if post or page slider is  active
	*
	* @since  Flat Commerce Pro 1.6
	*/
	function flat_commerce_is_post_and_page_slider_active( $control ) {
		global $wp_query;

		$page_id        = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
    	$page_on_front  = get_option('page_on_front') ;

		$enable         = $control->manager->get_setting( 'flat_commerce_theme_options[featured_slider_option]' )->value();

		$type           = $control->manager->get_setting( 'flat_commerce_theme_options[featured_slider_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and page slider
		return ( ( $enable == 'entire-site' || ( ( $page_id == $page_on_front && $page_id > 0  ) && $enable == 'homepage' ) ) && ( 'featured-page-slider' == $type || 'featured-post-slider' == $type ) );
	}
endif;

if( ! function_exists( 'flat_commerce_is_featured_product_active' ) ) :
	/**
	* Return true if featured content is active
	*
	* @since  Flat Commerce Pro 1.0
	*/
	function flat_commerce_is_featured_product_active( $control ) {
		global $wp_query;

		$page_id        = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
    	$page_on_front  = get_option('page_on_front') ;

		$enable         = $control->manager->get_setting( 'flat_commerce_theme_options[featured_product_content_option]' )->value();

		//return true only if previwed page on customizer matches the type of content option selected
		return ( $enable == 'entire-site' || ( ( $page_id == $page_on_front && $page_id > 0  ) && $enable == 'homepage' ) );
	}
endif;


if( ! function_exists( 'flat_commerce_is_demo_featured_product_content_inactive' ) ) :
	/**
	* Return true if demo featured content is inactive
	*
	* @since  Flat Commerce Pro 1.0
	*/
	function flat_commerce_is_demo_featured_product_content_inactive( $control ) {
		global $wp_query;

		$page_id        = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
    	$page_on_front  = get_option('page_on_front') ;

		$enable         = $control->manager->get_setting( 'flat_commerce_theme_options[featured_product_content_option]' )->value();

		$type           = $control->manager->get_setting( 'flat_commerce_theme_options[featured_product_content_type]' )->value();

		//return true only if previwed page on customizer matches the type of content option selected and is not demo content
		return ( ( $enable == 'entire-site' || ( ( $page_id == $page_on_front && $page_id > 0  ) && $enable == 'homepage' ) ) && !( 'demo-featured-content' == $type ) );
	}
endif;


if( ! function_exists( 'flat_commerce_is_featured_post_content_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since  Flat Commerce Pro 1.0
	*/
	function flat_commerce_is_featured_post_content_active( $control ) {
		global $wp_query;

		$page_id        = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
    	$page_on_front  = get_option('page_on_front') ;

		$enable         = $control->manager->get_setting( 'flat_commerce_theme_options[featured_product_content_option]' )->value();

		$type           = $control->manager->get_setting( 'flat_commerce_theme_options[featured_product_content_type]' )->value();

		//return true only if previwed page on customizer matches the type of content option selected and page content
		return ( ( $enable == 'entire-site' || ( ( $page_id == $page_on_front && $page_id > 0  ) && $enable == 'homepage' ) ) && ( 'featured-post-content' == $type ) );
	}
endif;


if( ! function_exists( 'flat_commerce_is_featured_product_content_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since  Flat Commerce Pro 1.0
	*/
	function flat_commerce_is_featured_product_content_active( $control ) {
		global $wp_query;

		$page_id        = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
    	$page_on_front  = get_option('page_on_front') ;

		$enable         = $control->manager->get_setting( 'flat_commerce_theme_options[featured_product_content_option]' )->value();

		$type           = $control->manager->get_setting( 'flat_commerce_theme_options[featured_product_content_type]' )->value();

		//return true only if previwed page on customizer matches the type of content option selected and page content
		return ( ( $enable == 'entire-site' || ( ( $page_id == $page_on_front && $page_id > 0  ) && $enable == 'homepage' ) ) && ( 'featured-product-content' == $type ) );
	}
endif;


if( ! function_exists( 'flat_commerce_is_featured_page_content_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since  Flat Commerce Pro 1.0
	*/
	function flat_commerce_is_featured_page_content_active( $control ) {
		global $wp_query;

		$page_id        = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
    	$page_on_front  = get_option('page_on_front') ;

		$enable         = $control->manager->get_setting( 'flat_commerce_theme_options[featured_product_content_option]' )->value();

		$type           = $control->manager->get_setting( 'flat_commerce_theme_options[featured_product_content_type]' )->value();

		//return true only if previwed page on customizer matches the type of content option selected and page content
		return ( ( $enable == 'entire-site' || ( ( $page_id == $page_on_front && $page_id > 0  ) && $enable == 'homepage' ) ) && ( 'featured-page-content' == $type ) );
	}
endif;


if( ! function_exists( 'flat_commerce_is_featured_category_content_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since  Flat Commerce Pro 1.0
	*/
	function flat_commerce_is_featured_category_content_active( $control ) {
		global $wp_query;

		$page_id        = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
    	$page_on_front  = get_option('page_on_front') ;

		$enable         = $control->manager->get_setting( 'flat_commerce_theme_options[featured_product_content_option]' )->value();

		$type           = $control->manager->get_setting( 'flat_commerce_theme_options[featured_product_content_type]' )->value();

		//return true only if previwed page on customizer matches the type of content option selected and page content
		return ( ( $enable == 'entire-site' || ( ( $page_id == $page_on_front && $page_id > 0  ) && $enable == 'homepage' ) ) && ( 'featured-category-content' == $type ) );
	}
endif;


if( ! function_exists( 'flat_commerce_is_featured_image_content_active' ) ) :
	/**
	* Return true if page content is active
	*
	* @since  Flat Commerce Pro 1.0
	*/
	function flat_commerce_is_featured_image_content_active( $control ) {
		global $wp_query;

		$page_id        = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
    	$page_on_front  = get_option('page_on_front') ;

		$enable         = $control->manager->get_setting( 'flat_commerce_theme_options[featured_product_content_option]' )->value();

		$type           = $control->manager->get_setting( 'flat_commerce_theme_options[featured_product_content_type]' )->value();

		//return true only if previwed page on customizer matches the type of content option selected and page content
		return ( ( $enable == 'entire-site' || ( ( $page_id == $page_on_front && $page_id > 0  ) && $enable == 'homepage' ) ) && ( 'featured-image-content' == $type ) );
	}
endif;


if( ! function_exists( 'flat_commerce_is_featured_product_content_background_image_enabled' ) ) :
	/**
	* Return true if featured content background image is not disabled
	*
	* @since  Flat Commerce Pro 1.0
	*/
	function flat_commerce_is_featured_product_content_background_image_enabled( $control ) {
		return !$control->manager->get_setting( 'flat_commerce_theme_options[featured_product_content_disable_background_image]' )->value();
	}
endif;


if( !function_exists( 'is_featured_product_content_subheadline_choice_set' ) ):
	/**
	* Returns true is product slider is active
	*
	* @since Flat Commerce Pro 1.0
	*/
	function is_featured_product_content_subheadline_choice_set( $control ){
		$radio_setting = $control->manager->get_setting( 'flat_commerce_theme_options[featured_product_content_subheadline]' )->value();
		$control_id    = $control->id;

	    if ( $control_id == 'flat_commerce_theme_options[featured_product_content_subheadline_text]'  && $radio_setting == 'text' ) return true;
	    if ( $control_id == 'flat_commerce_theme_options[featured_product_content_subheadline_image]' && $radio_setting == 'image' ) return true;

	    return false;
	}
endif;

if( ! function_exists( 'flat_commerce_is_bottom_section_active' ) ) :
	/**
	* Return true if about us section  is not disabled
	* @since  Flat Commerce Pro 1.0
	*/

	function flat_commerce_is_bottom_section_active( $control ) {
		global $wp_query;

		$page_id               = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
    	$page_on_front  = get_option('page_on_front') ;

		$enable = $control->manager->get_setting( 'flat_commerce_theme_options[bottom_section_enable_option]' )->value();
		//return true only if previwed page on customizer matches the option selected

		return  ( $enable == 'entire-site' || ( ( $page_id == $page_on_front && $page_id > 0  ) && $enable == 'homepage' ) );
	}

endif;


if( ! function_exists( 'flat_commerce_is_custom_content_type_active' ) ) :
	/**
	* Return true if content type is custom
	* @since  Flat Commerce Pro 1.0
	*/

	function flat_commerce_is_custom_content_type_active( $control ) {

		$enable = flat_commerce_is_bottom_section_active( $control );

		$content_type = $control->manager->get_setting( 'flat_commerce_theme_options[bottom_section_content_type]' )->value();

		return  ( $enable && ( $content_type == 'custom' ) );
	}

endif;


if( ! function_exists( 'flat_commerce_is_page_content_type_active' ) ) :
	/**
	* Return true if content type is page
	* @since  Flat Commerce Pro 1.0
	*/

	function flat_commerce_is_page_content_type_active( $control ) {

		$enable       = flat_commerce_is_bottom_section_active( $control );

		$content_type = $control->manager->get_setting( 'flat_commerce_theme_options[bottom_section_content_type]' )->value();

		return  ( $enable && ( $content_type == 'page' ) );
	}

endif;


if( ! function_exists( 'flat_commerce_is_bottom_section_read_more_link_enabled' ) ):
	/**
	* Returns true is product slider is active
	*
	* @since Flat Commerce 1.0
	*/
	function flat_commerce_is_bottom_section_read_more_link_enabled( $control ){
		global $wp_query;

		$page_id        = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
    	$page_on_front  = get_option('page_on_front') ;

		$enable         = $control->manager->get_setting( 'flat_commerce_theme_options[bottom_section_enable_option]' )->value();

		$radio_setting  = $control->manager->get_setting( 'flat_commerce_theme_options[bottom_section_read_more_link]' )->value();

		return  ( ( $enable == 'entire-site' || ( ( $page_id == $page_on_front && $page_id > 0  ) && $enable == 'homepage' ) )  && $radio_setting  );
		}
endif;


if( ! function_exists( 'flat_commerce_is_bottom_section_read_more_link_custom_type_enabled' ) ):
	/**
	* Returns true is product slider is active
	*
	* @since Flat Commerce 1.0
	*/
	function flat_commerce_is_bottom_section_read_more_link_custom_type_enabled( $control ){

		$enable        = flat_commerce_is_bottom_section_active( $control );

		$radio_setting = $control->manager->get_setting( 'flat_commerce_theme_options[bottom_section_read_more_link]' )->value();

		$content_type  = $control->manager->get_setting( 'flat_commerce_theme_options[bottom_section_content_type]' )->value();

		return  ( $enable  && $radio_setting && ( $content_type == 'custom' ) );
	}
endif;


if( ! function_exists( 'flat_commerce_is_bottom_section_social_media_enabled' ) ):
	/**
	* Returns true is product slider is active
	*
	* @since Flat Commerce 1.0
	*/
	function flat_commerce_is_bottom_section_social_media_enabled( $control ) {
		global $wp_query;

		$page_id               = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
    	$page_on_front  = get_option('page_on_front') ;

		$enable = $control->manager->get_setting( 'flat_commerce_theme_options[bottom_section_enable_option]' )->value();

		$radio_setting = $control->manager->get_setting( 'flat_commerce_theme_options[bottom_section_social_media]' )->value();

		return  ( ( $enable == 'entire-site' || ( ( $page_id == $page_on_front && $page_id > 0  ) && $enable == 'homepage' ) )  && $radio_setting );
	}
endif;


//Product Slider Active Callback Functions
if( ! function_exists( 'flat_commerce_is_product_slider_active' ) ):
	/**
	* Returns true is product slider is active
	*
	* @since Flat Commerce 1.0
	*/
	function flat_commerce_is_product_slider_active( $control ) {

		global $wp_query;

		$page_id        = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
    	$page_on_front  = get_option('page_on_front') ;

		$enable         = $control->manager->get_setting( 'flat_commerce_theme_options[product_slider_option]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected
		return ( $enable == 'entire-site' || ( ( $page_id == $page_on_front && $page_id > 0  ) && $enable == 'homepage' ) );

	}
endif;

if( ! function_exists( 'flat_commerce_is_product_category_slider_active' ) ):
	/**
	* Returns true is product slider is active
	*
	* @since Flat Commerce 1.0
	*/
	function flat_commerce_is_product_category_slider_active( $control ) {

		global $wp_query;

		$page_id        = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
    	$page_on_front  = get_option('page_on_front') ;

		$enable         = $control->manager->get_setting( 'flat_commerce_theme_options[product_slider_option]' )->value();

		$type           = $control->manager->get_setting( 'flat_commerce_theme_options[product_slider_type_select]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and page slider
		return ( ( $enable == 'entire-site' || ( ( $page_id == $page_on_front && $page_id > 0  ) && $enable == 'homepage' ) ) && ( 'category-product-slider' == $type ) );
	}
endif;

if( ! function_exists( 'flat_commerce_is_product_banner_active' ) ):

	function flat_commerce_is_product_banner_active( $control ) {


		$banner_control        = $control->manager->get_setting( 'flat_commerce_theme_options[product_slider_exclusive_banner_control]' )->value();


		$product_slider_option = $control->manager->get_setting( 'flat_commerce_theme_options[product_slider_option]' )->value();


		return ( $banner_control == 0  && $product_slider_option != 'disabled' ) ? true: false;
	}
endif;


//Recent Products Active Callback Functions
if( ! function_exists( 'flat_commerce_is_recent_products_active' ) ) :
	/**
	* Return true if slider is active
	*
	* @since  Flat Commerce Pro 1.0
	*/
	function flat_commerce_is_recent_products_active( $control ) {
		global $wp_query;

		$page_id        = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
    	$page_on_front  = get_option('page_on_front') ;

		$enable         = $control->manager->get_setting( 'flat_commerce_theme_options[recent_products_option]' )->value();

		//return true only if previwed page on customizer matches the option selected
		return ( $enable == 'entire-site' || ( ( $page_id == $page_on_front && $page_id > 0  ) && $enable == 'homepage' ) );
	}
endif;


if( ! function_exists( 'flat_commerce_is_recent_products_featured_active' ) ) :
	/**
	* Return true if featured  is active
	* @since  Flat Commerce Pro 1.0
	*/

	function flat_commerce_is_recent_products_featured_active( $control ) {
		global $wp_query;

		$page_id               = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
    	$page_on_front  = get_option('page_on_front') ;

		$recent_product_option = $control->manager->get_setting( 'flat_commerce_theme_options[recent_products_option]' )->value();

		$control_option        = $control->manager->get_setting( 'flat_commerce_theme_options[recent_products_option_select]' ) ->value();

		//return true only if previwed page on customizer matches the option selected
		return ( ( $recent_product_option == 'entire-site' || ( ( $page_id == $page_on_front && $page_id > 0  ) && $recent_product_option == 'homepage' ) ) &&  $control_option == 'recent-product-featured') ? true: false;
	}

endif;

// google map active
if( ! function_exists( 'flat_commerce_is_google_map_enable' ) ) :
	/**
	* Return true if google map is enabled
	*
	* @since  Flat Commerce Pro 1.0
	*/
	function flat_commerce_is_google_map_enable( $control ) {
		$banner_control = $control->manager->get_setting( 'flat_commerce_theme_options[disable_google_map]' )->value();

		return ( $banner_control == false ) ? true : false;
	}
endif;


if( ! function_exists( 'flat_commerce_is_contact_info_type_field_selected' ) ) :
	/**
	* Return true if page slider is active
	*
	* @since  Flat Commerce Pro 1.0
	*/
	function flat_commerce_is_contact_social_type_field_selected( $control ) {
		$no_of_tabs = $control->manager->get_setting( 'flat_commerce_theme_options[additional_fields_number]' )->value();

		for( $i = 1; $i <= $no_of_tabs; $i++ ){
			$enable[] = $control->manager->get_setting( 'flat_commerce_theme_options[contact_type_of_field_1]' )->value();
		}

		if ( ( $enable == 'social' ) ) {
			return true;
		} else {
			return false;
		}
	}//return true only if previwed page on customizer matches the type of slider option selected and page slider
endif;

// topbar active
if( ! function_exists( 'flat_commerce_is_topbar_enable' ) ) :
	/**
	* Return true if topbar is enabled
	*
	* @since  Flat Commerce Pro 1.3
	*/
	function flat_commerce_is_topbar_enable( $control ) {
		$topbar_control = $control->manager->get_setting( 'flat_commerce_theme_options[enable_topbar]' )->value();

		return ( $topbar_control == true ) ? true : false;
	}
endif;

if ( ! function_exists( 'flat_commerce_is_topbar_social_enable' ) ) :
	/**
	 * Check if topbar social is enabled.
	 *
	 * @since Flat Commerce 1.6
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function flat_commerce_is_topbar_social_enable( $control ) {
		$content_type = $control->manager->get_setting( 'flat_commerce_theme_options[topbar_social_enable]' )->value();
		if ( flat_commerce_is_topbar_enable( $control ) &&  true === $content_type )
			return true;
		else
			return false;
	}
endif;

//Front page blog Active Callback Functions
if( ! function_exists( 'flat_commerce_is_frontpage_blog_enable' ) ):
	/**
	* Returns true is product slider is active
	*
	* @since Flat Commerce 1.0
	*/
	function flat_commerce_is_frontpage_blog_enable( $control ) {

		global $wp_query;

		$page_id        = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
    	$page_on_front  = get_option('page_on_front') ;

		$enable         = $control->manager->get_setting( 'flat_commerce_theme_options[latest_blog_content_option]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected
		return ( $enable == 'entire-site' || ( ( $page_id == $page_on_front && $page_id > 0  ) && $enable == 'homepage' ) );

	}
endif;

if( ! function_exists( 'flat_commerce_is_demo_front_page_blog_inactive' ) ) :
	/**
	* Return true if demo front page blog is inactive
	*
	* @since  Flat Commerce Pro 1.0
	*/
	function flat_commerce_is_demo_front_page_blog_inactive( $control ) {
	

		$type           = $control->manager->get_setting( 'flat_commerce_theme_options[latest_blog_content_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected and is not demo slider
		return ( flat_commerce_is_frontpage_blog_enable( $control ) && !( 'demo-latest-blog-content' == $type ) );
	}
endif;

if( ! function_exists( 'flat_commerce_is_logo_slider_active' ) ) :
	/**
	* Return true if logo slider section  is not disabled
	* @since  Flat Commerce Pro 1.0
	*/

	function flat_commerce_is_logo_slider_active( $control ) {
		global $wp_query;

		$page_id               = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
    	$page_on_front  = get_option('page_on_front') ;

		$enable = $control->manager->get_setting( 'flat_commerce_theme_options[logo_slider_enable_option]' )->value();
		//return true only if previwed page on customizer matches the option selected

		return  ( $enable == 'entire-site' || ( ( $page_id == $page_on_front && $page_id > 0  ) && $enable == 'homepage' ) );
	}

endif;