<?php
/**
 * The template for adding Customizer Custom Controls
 *
 * @package Theme Palace
 * @subpackage Flat Commerce Pro
 * @since Flat Commerce Pro 1.0
 */

if ( ! defined( 'FLAT_COMMERCE_THEME_VERSION' ) ) {
	header( 'Status: 403 Forbidden' );
	header( 'HTTP/1.1 403 Forbidden' );
	exit();
}

	//Custom control for dropdown post category
	class Flat_Commerce_Post_Dropdown_Categories_Control extends WP_Customize_Control {
		public $type = 'post-dropdown-categories';

		public $name;

		public function render_content() {
			$dropdown = wp_dropdown_categories(
				array(
					'show_option_all'  => 'All Categories',
					'name'             => $this->name,
					'echo'             => 0,
					'hide_empty'       => false,
					'show_option_none' => false,
					'hide_if_empty'    => false,
				)
			);

			$dropdown = str_replace('<select', '<select style = "height:30px;" ' . $this->get_link(), $dropdown );

			printf(
				'<label class="customize-control-select"><span class="customize-control-title">%s</span> %s</label>',
				$this->label,
				$dropdown
			);

		}
	}


	//Custom control for dropdown category multiple select
	class Flat_Commerce_Customize_Dropdown_Categories_Control extends WP_Customize_Control {
		public $type = 'dropdown-categories';

		public $name;

		public function render_content() {
			$dropdown = wp_dropdown_categories(
				array(
					'name'             => $this->name,
					'echo'             => 0,
					'hide_empty'       => false,
					'show_option_none' => false,
					'hide_if_empty'    => false,
				)
			);

			$dropdown = str_replace('<select', '<select multiple = "multiple" style = "height:95px;" ' . $this->get_link(), $dropdown );

			printf(
				'<label class="customize-control-select"><span class="customize-control-title">%s</span> %s</label>',
				$this->label,
				$dropdown
			);

			echo '<p class="description">'. __( 'Hold down the Ctrl (windows) / Command (Mac) button to select multiple options.', 'flat-commerce' ) . '</p>';
		}
	}

	//Custom control for dropdown category multiple select
	class Flat_Commerce_Customize_Dropdown_Product_Categories_Control extends WP_Customize_Control {
		public $type = 'dropdown-categories';

		public $name;

		public function render_content() {
			$dropdown = wp_dropdown_categories(
				array(
					'name'             => $this->name,
					'echo'             => 0,
					'hide_empty'       => false,
					'show_option_none' => false,
					'hide_if_empty'    => false,
					'taxonomy'         => 'product_cat'
				)
			);

			$dropdown = str_replace('<select', '<select multiple = "multiple" style = "height:95px;" ' . $this->get_link(), $dropdown );

			printf(
				'<label class="customize-control-select"><span class="customize-control-title">%s</span> %s</label>',
				$this->label,
				$dropdown
			);

			echo '<p class="description">'. esc_html__( 'Hold down the Ctrl (windows) / Command (Mac) button to select multiple options.', 'flat-commerce' ) . '</p>';
		}
	}


	//Custom control for any note, use label as output description
	class Flat_Commerce_Note_Control extends WP_Customize_Control {
		public $type = 'description';

		public function render_content() {
			echo '<h2 class="description">' . $this->label . '</h2>';
			echo '<p class="description">' . $this->description . '</p>';
		}
	}

	//Custom control for dropdown category multiple select
	class Flat_Commerce_Important_Links extends WP_Customize_Control {
        public $type = 'important-links';

        public function render_content() {
        	//Add Theme instruction, Support Forum, Changelog, Donate link, Review, Facebook, Twitter, Google+, Pinterest links
            $important_links = array(
							'theme_instructions' => array(
								'link'	=> esc_url( 'http://themepalace.com/theme-instructions/flat-commerce-pro/' ),
								'text' 	=> esc_html__( 'Theme Instructions', 'flat-commerce' ),
								),
							'support' => array(
								'link'	=> esc_url( 'http://themepalace.com/forum/flat-commerce-pro/' ),
								'text' 	=> esc_html__( 'Support', 'flat-commerce' ),
								),
							'facebook' => array(
								'link'	=> esc_url( 'https://www.facebook.com/themepalace/' ),
								'text' 	=> esc_html__( 'Facebook', 'flat-commerce' ),
								),
							'twitter' => array(
								'link'	=> esc_url( 'https://twitter.com/themepalace/' ),
								'text' 	=> esc_html__( 'Twitter', 'flat-commerce' ),
								),
							);
			foreach ( $important_links as $important_link) {
				echo '<p><a target="_blank" href="' . esc_url( $important_link['link'] ) .'" >' . esc_attr( $important_link['text'] ) .' </a></p>';
			}
      }
   }

//Custom control for WC dropdown products category multiple select
class Flat_Commerce_Customize_WC_Dropdown_Product_Categories extends WP_Customize_Control {
	public $type = 'wc-dropdown-categories';

	public $name;

	public function render_content() {
		$dropdown = wp_dropdown_categories(
			array(
				'name'             => $this->name,
				'echo'             => 0,
				'hide_empty'       => false,
				'show_option_none' => false,
				'hide_if_empty'    => false,
				'taxonomy'         => 'product_cat',
			)
		);

		$dropdown = str_replace('<select', '<select multiple = "multiple" style = "height:95px;" ' . $this->get_link(), $dropdown );

		printf(
			'<label class="customize-control-select"><span class="customize-control-title">%s</span> %s</label>',
			$this->label,
			$dropdown
		);

		echo '<p class="description">'. esc_html__( 'Hold down the Ctrl (windows) / Command (Mac) button to select multiple options.', 'flat-commerce' ) . '</p>';
	}
}

//Custom control for WC dropdown single category select
class Flat_Commerce_Customize_WC_Dropdown_Product_Category extends WP_Customize_Control {
	public $type = 'wc-dropdown-category';

	public $name;

	public function render_content() {
		$dropdown = wp_dropdown_categories(
			array(
				'name'             => $this->name,
				'echo'             => 0,
				'hide_empty'       => false,
				'show_option_none' => false,
				'hide_if_empty'    => false,
				'taxonomy'         => 'product_cat',
			)
		);

		$dropdown = str_replace('<select', '<select style = "height:25px;" ' . $this->get_link(), $dropdown );

		printf(
			'<label class="customize-control-select"><span class="customize-control-title">%s</span> %s</label>',
			$this->label,
			$dropdown
		);

		echo '<p class="description">'. esc_html__( 'Select Product Category', 'flat-commerce' ) . '</p>';
	}
}