<?php
/**
 * The template for adding Featured Product Content Settings in Customizer
 *
 * @package Theme Palace
 * @subpackage Flat Commerce Pro
 * @since Flat Commerce Pro 1.0
 */

//Homepage / Static Frontpage Options
$wp_customize->add_section( 'flat_commerce_homepage_options', array(
	'description'	=> __( 'Go to ( Settings->Reading->Blog pages show at most) to change no of blog posts visible', 'flat-commerce' ),
	'priority' 		=> 510,
	'title'   	 	=> __( 'Frontpage Blog', 'flat-commerce' ),
) );

// Latest Blog options
$wp_customize->add_setting( 'flat_commerce_theme_options[latest_blog_content_option]', array(
    'capability'        => 'edit_theme_options',
    'default'           => $defaults['latest_blog_content_option'],
    'sanitize_callback' => 'flat_commerce_sanitize_select',
) );

$latest_blog_content_options = flat_commerce_latest_blog_content_options();
$choices = array();

foreach ( $latest_blog_content_options as $latest_blog_content_option ) {

    $choices[$latest_blog_content_option['value']] = $latest_blog_content_option['label'];

}

$wp_customize->add_control( 'flat_commerce_theme_options[latest_blog_content_option]', array(
    'label'             => esc_html__( 'Enable blog on', 'flat-commerce' ),
    'priority'          => '1.1',
    'section'           => 'flat_commerce_homepage_options',
    'settings'          => 'flat_commerce_theme_options[latest_blog_content_option]',
    'type'              => 'select',
    'choices'           => $choices,
) );

// Front Page Blog Type
$wp_customize->add_setting( 'flat_commerce_theme_options[latest_blog_content_type]', array(
    'capability'        => 'edit_theme_options',
    'default'           => $defaults['latest_blog_content_type'],
    'sanitize_callback' => 'sanitize_key',
) );

$latest_blog_content_types = flat_commerce_latest_blog_content_types();
$choices = array();

foreach ( $latest_blog_content_types as $latest_blog_content_type ) {

    $choices[$latest_blog_content_type['value']] = $latest_blog_content_type['label'];

}

$wp_customize->add_control( 'flat_commerce_theme_options[latest_blog_content_type]', array(
    'active_callback'   => 'flat_commerce_is_frontpage_blog_enable',
    'label'             => esc_html__( 'Select Latest Blog Type', 'flat-commerce' ),
    'priority'          => '1.2',
    'section'           => 'flat_commerce_homepage_options',
    'settings'          => 'flat_commerce_theme_options[latest_blog_content_type]',
    'type'              => 'select',
    'choices'           => $choices,
));

 // Blog heading
$wp_customize->add_setting( 'flat_commerce_theme_options[latest_blog_heading]', array(
    'capability'        => 'edit_theme_options',
    'default'           => $defaults['latest_blog_heading'],
    'sanitize_callback' => 'sanitize_text_field',
) );


$wp_customize->add_control( 'flat_commerce_theme_options[latest_blog_heading]' , array(
    'active_callback'   => 'flat_commerce_is_demo_front_page_blog_inactive',
    'label'         => __( 'Heading', 'flat-commerce' ),
    'priority'      => '5',
    'section'       => 'flat_commerce_homepage_options',
    'settings'      => 'flat_commerce_theme_options[latest_blog_heading]',
    )
);

$wp_customize->add_setting( 'flat_commerce_theme_options[front_page_category]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['front_page_category'],
	'sanitize_callback'	=> 'flat_commerce_sanitize_category_list',
) );

$wp_customize->add_control( new Flat_Commerce_Post_Dropdown_Categories_Control( $wp_customize, 'flat_commerce_theme_options[front_page_category]', array(
    'active_callback'   => 'flat_commerce_is_demo_front_page_blog_inactive',
    'label'   	=> __( 'Select Categories', 'flat-commerce' ),
    'name'	 	=> 'flat_commerce_theme_options[front_page_category]',
	'priority'	=> '6',
    'section'  	=> 'flat_commerce_homepage_options',
    'settings' 	=> 'flat_commerce_theme_options[front_page_category]',
    'type'     	=> 'post-dropdown-categories',
) ) );

 // Layout

 $wp_customize->add_setting( 'flat_commerce_theme_options[latest_blog_layout]', array(
     'capability'        => 'edit_theme_options',
     'default'           => $defaults['latest_blog_layout'],
     'sanitize_callback' => 'flat_commerce_sanitize_number_range',
 ) );

 $wp_customize->add_control( 'flat_commerce_theme_options[latest_blog_layout]', array(
    'active_callback'   => 'flat_commerce_is_demo_front_page_blog_inactive',
     'label'     => __( 'Posts Layout', 'flat-commerce' ),
     'description' => __('Layout option for posts. Maximum number of layout is 4.', 'flat-commerce'),
     'priority'  => 30,
     'section'   => 'flat_commerce_homepage_options',
     'settings'  => 'flat_commerce_theme_options[latest_blog_layout]',
     'type'      => 'number',
     'input_attrs' => array(
         'style' => 'width: 40px;',
         'max' => 5,
         'min' => 1,
         )
 ) );

 // Number of products
 $wp_customize->add_setting( 'flat_commerce_theme_options[latest_blog_posts_number]', array(
     'capability'        => 'edit_theme_options',
     'default'           => $defaults['latest_blog_posts_number'],
     'sanitize_callback' => 'flat_commerce_sanitize_number_range',
 ) );

 $wp_customize->add_control( 'flat_commerce_theme_options[latest_blog_posts_number]', array(
    'active_callback'   => 'flat_commerce_is_demo_front_page_blog_inactive',
     'label'     => __( 'Number of Posts', 'flat-commerce' ),
     'priority'  => 40,
     'section'   => 'flat_commerce_homepage_options',
     'settings'  => 'flat_commerce_theme_options[latest_blog_posts_number]',
     'type'      => 'number',
     'input_attrs' => array(
         'style' => 'width: 40px;',
         'max' => 6,
         'min' => 1,
         )
 ) );

//Homepage / Static Frontpage Settings End