<?php
/**
 * The template for adding Featured Slider Options in Customizer
 *
 * @package Theme Palace
 * @subpackage Flat Commerce Pro
 * @since Flat Commerce Pro 1.0
 */

if ( ! defined( 'FLAT_COMMERCE_THEME_VERSION' ) ) {
	header( 'Status: 403 Forbidden' );
	header( 'HTTP/1.1 403 Forbidden' );
	exit();
}
	$wp_customize -> add_section( 'flat_commerce_recent_products', array(
		'priority'			=> 500,
		'title'				=> esc_html__( 'Recent Products', 'flat-commerce' ),
	) );

	// recent product options
	$wp_customize -> add_setting( 'flat_commerce_theme_options[recent_products_option]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['recent_products_option'],
		'sanitize_callback' => 'flat_commerce_sanitize_select',
	) );

	$recent_products_content_options = flat_commerce_get_recent_products_options();
	$choices = array();

	foreach ( $recent_products_content_options as $recent_products_content_option ) {

		$choices[$recent_products_content_option['value']] = $recent_products_content_option['label'];

	}

	$wp_customize -> add_control( 'flat_commerce_theme_options[recent_products_option]', array(
		'choices'   		=> $choices,
		'label'    			=> esc_html__( 'Enable Recent Products on', 'flat-commerce' ),
		'priority'			=> '1.1',
		'section'  			=> 'flat_commerce_recent_products',
		'setting'			=> 'flat_commerce_theme_options[recent_products_option]',
		'type'    			=> 'select',
	) );

	// recent product title
	$wp_customize -> add_setting( 'flat_commerce_theme_options[recent_products_title]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['recent_products_title'],
		'transport'			=> 'postMessage',
		'sanitize_callback' => 'sanitize_text_field',
	) );

	// Abort if selective refresh is not available.
	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'flat_commerce_theme_options[recent_products_title]', array(
			'selector'            => '#recent-product .entry-header h2.entry-title',
			'render_callback'     => 'flat_commerce_customize_partial_recent_products_title',
			'container_inclusive' => false,
			'fallback_refresh'    => true,
		) );
	}

	$wp_customize -> add_control( 'flat_commerce_theme_options[recent_products_title]', array(
		'active_callback'   => 'flat_commerce_is_recent_products_active',
		'label'    			=> esc_html__( 'Title', 'flat-commerce' ),
		'priority'			=> '1.2',
		'section'  			=> 'flat_commerce_recent_products',
		'setting'			=> 'flat_commerce_theme_options[recent_products_title]',
	) );


	// recent products options select
	$wp_customize -> add_setting( 'flat_commerce_theme_options[recent_products_option_select]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['recent_products_option_select'],
		'sanitize_callback' => 'sanitize_key',

	) );

	$recent_product_options = flat_commerce_get_recent_products_type_select();
	$choices 		= array();

	foreach ( $recent_product_options as $recent_product_option ) {

		$choices[ $recent_product_option['value'] ] = $recent_product_option['label'];

	}

	$wp_customize -> add_control( 'flat_commerce_theme_options[recent_products_option_select]', array(
		'active_callback' 	=> 'flat_commerce_is_recent_products_active',
		'label'    			=> esc_html__( 'Select Recent Product Type', 'flat-commerce' ),
		'priority'			=> '1.3',
		'section'  			=> 'flat_commerce_recent_products',
		'setting'			=> 'flat_commerce_theme_options[recent_products_option_select]',
		'type'    			=> 'select',
		'choices'			=> $choices
	));

	// recent products title control
	$wp_customize -> add_setting( 'flat_commerce_theme_options[recent_products_title_control]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['recent_products_title_control'],
		'sanitize_callback' => 'flat_commerce_sanitize_checkbox',
	) );

	$wp_customize -> add_control( 'flat_commerce_theme_options[recent_products_title_control]', array(
		'active_callback' 	=> 'flat_commerce_is_recent_products_active',
		'label'    			=> esc_html__( 'Check to disable title', 'flat-commerce' ),
		'priority'			=> '1.4',
		'section'  			=> 'flat_commerce_recent_products',
		'setting'			=> 'flat_commerce_theme_options[recent_products_title_control]',
		'type'    			=> 'checkbox',
	));

	// recent products content layout
	$wp_customize -> add_setting( 'flat_commerce_theme_options[recent_products_content_layout]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['recent_products_content_layout'],
		'sanitize_callback' => 'flat_commerce_sanitize_select',
	) );

	$flat_commerce_recent_product_layout_options = flat_commerce_recent_product_layout_options();
	$choices = array();
	foreach ( $flat_commerce_recent_product_layout_options as $flat_commerce_recent_product_layout_option ) {
		$choices[$flat_commerce_recent_product_layout_option['value']] = $flat_commerce_recent_product_layout_option['label'];
	}

	$wp_customize -> add_control( 'flat_commerce_theme_options[recent_products_content_layout]', array(
		'active_callback' 	=> 'flat_commerce_is_recent_products_featured_active',
		'label'    			=> esc_html__( 'Layout Option', 'flat-commerce' ),
		'priority'			=> '1.5',
		'section'  			=> 'flat_commerce_recent_products',
		'setting'			=> 'flat_commerce_theme_options[recent_products_content_layout]',
		'type'    			=> 'select',
		'choices'         => $choices
	));

	// recent products visible no
	$wp_customize -> add_setting( 'flat_commerce_theme_options[recent_products_visible_no]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['recent_products_visible_no'],
		'sanitize_callback' => 'flat_commerce_sanitize_number_range',
		'validate_callback' => 'flat_commerce_validate_recent_products_visible_no'
	) );

	$wp_customize -> add_control( 'flat_commerce_theme_options[recent_products_visible_no]', array(
		'active_callback' 	=> 'flat_commerce_is_recent_products_featured_active',
		'label'    			=> esc_html__( 'Number of products to show', 'flat-commerce' ),
		'description' 		=> esc_html__( 'Enter number from 1 and 10', 'flat-commerce'),
		'priority'			=> '1.7',
		'section'  			=> 'flat_commerce_recent_products',
		'setting'			=> 'flat_commerce_theme_options[recent_products_visible_no]',
		'type'    			=> 'number',
		'input_attrs' 		=> array(
            'min'   	=> 1,
            'max'		=> 10,
            'style' 	=> 'width: 60px;'
		),
	));

	// recent products add to cart text
	$wp_customize -> add_setting( 'flat_commerce_theme_options[recent_products_add_to_cart_text]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['recent_products_add_to_cart_text'],
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize  ->  add_control( 'flat_commerce_theme_options[recent_products_add_to_cart_text]', array(
		'active_callback' 	=> 'flat_commerce_is_recent_products_featured_active',
		'label'           	=> esc_html__( 'Button Text', 'flat-commerce' ),
		'priority'        	=> '1.8',
		'section'         	=> 'flat_commerce_recent_products',
		'setting'         	=> 'flat_commerce_theme_options[recent_products_add_to_cart_text]'
	) );

	// recent products view more text
	$wp_customize -> add_setting( 'flat_commerce_theme_options[recent_products_view_more_text]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['recent_products_view_more_text'],
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize  ->  add_control( 'flat_commerce_theme_options[recent_products_view_more_text]', array(
		'active_callback' 	=> 'flat_commerce_is_recent_products_featured_active',
		'label'           	=> esc_html__( 'View More Text', 'flat-commerce' ),
		'priority'        	=> '1.9',
		'section'         	=> 'flat_commerce_recent_products',
		'setting'         	=> 'flat_commerce_theme_options[recent_products_view_more_text]',
	) );

// Recent Products Customizer Options End