<?php
/**
 * The template for Social Links in Customizer
 *
 * @package Theme Palace
 * @subpackage Flat Commerce
 * @since Flat Commerce Pro 1.0
 */

if ( ! defined( 'FLAT_COMMERCE_THEME_VERSION' ) ) {
	header( 'Status: 403 Forbidden' );
	header( 'HTTP/1.1 403 Forbidden' );
	exit();
}

	// Social Icons
	$wp_customize->add_panel( 'flat_commerce_social_links', array(
	    'capability'     => 'edit_theme_options',
	    'description'	=> esc_html__( 'Note: Enter the url for correponding social networking website', 'flat-commerce' ),
	    'priority'       => 700,
		'title'    		 => esc_html__( 'Social Links', 'flat-commerce' ),
	) );

	$wp_customize->add_section( 'flat_commerce_social_links', array(
		'panel'			=> 'flat_commerce_social_links',
		'priority' 		=> 1,
		'title'   	 	=> esc_html__( 'Social Links', 'flat-commerce' ),
	) );

	$wp_customize->add_setting( 'flat_commerce_theme_options[social_icon_size]', array(
		'capability'		=> 'edit_theme_options',
		'default' 			=> $defaults['social_icon_size'],
		'sanitize_callback'	=> 'absint',
	) );

	$wp_customize->add_control( 'flat_commerce_theme_options[social_icon_size]', array(
		'input_attrs' => array(
            'min'   => 10,
            'max'   => 200,
            'step'  => 5,
            'style' => 'width: 60px;'
            ),
		'label'    	=> esc_html__( 'Social Icon Size(px)', 'flat-commerce' ),
		'priority'	=> '1.5',
		'section' 	=> 'flat_commerce_social_links',
		'settings'	=> 'flat_commerce_theme_options[social_icon_size]',
		'type'	   => 'number',
		)
	);


	$flat_commerce_social_icons 	=	flat_commerce_get_social_icons_list();

	foreach ( $flat_commerce_social_icons as $key => $value ){
		if( 'skype_link' == $key ){
			$wp_customize->add_setting( 'flat_commerce_theme_options['. $key .']', array(
					'capability'		=> 'edit_theme_options',
					'sanitize_callback' => 'esc_attr',
				) );

			$wp_customize->add_control( 'flat_commerce_theme_options['. $key .']', array(
				'description'	=> __( 'Skype link can be of formats:<br>callto://+{number}<br> skype:{username}?{action}. More Information in readme file', 'flat-commerce' ),
				'label'    		=> $value['label'],
				'section'  		=> 'flat_commerce_social_links',
				'settings' 		=> 'flat_commerce_theme_options['. $key .']',
				'type'	   		=> 'url',
			) );
		}
		else {
			if( 'email_link' == $key ){
				$wp_customize->add_setting( 'flat_commerce_theme_options['. $key .']', array(
						'capability'		=> 'edit_theme_options',
						'sanitize_callback' => 'sanitize_email',
					) );
			}
			else if( 'handset_link' == $key || 'phone_link' == $key ){
				$wp_customize->add_setting( 'flat_commerce_theme_options['. $key .']', array(
						'capability'		=> 'edit_theme_options',
						'sanitize_callback' => 'sanitize_text_field',
					) );
			}
			else {
				$wp_customize->add_setting( 'flat_commerce_theme_options['. $key .']', array(
						'capability'		=> 'edit_theme_options',
						'sanitize_callback' => 'esc_url_raw',
					) );
			}

			$wp_customize->add_control( 'flat_commerce_theme_options['. $key .']', array(
				'label'    => $value['label'],
				'section'  => 'flat_commerce_social_links',
				'settings' => 'flat_commerce_theme_options['. $key .']',
				'type'	   => 'url',
			) );
		}
	}

	$wp_customize->add_section( 'flat_commerce_custom_social_links', array(
		'description'	=> esc_html__( 'Save and refresh the page if No. of custom social icon is changed (Max number of icons is 10)', 'flat-commerce' ),
		'panel'			=> 'flat_commerce_social_links',
		'priority' 		=> 2,
		'title'   	 	=> esc_html__( 'Custom Social Links', 'flat-commerce' ),
	) );

	$wp_customize->add_setting( 'flat_commerce_theme_options[custom_social_icons]', array(
		'capability'		=> 'edit_theme_options',
		'default' 			=> $defaults['custom_social_icons'],
		'sanitize_callback'	=> 'flat_commerce_sanitize_number_range',
		'validate_callback' => 'flat_commerce_validate_custom_social_icons'
		)
	);

	$wp_customize->add_control( 'flat_commerce_theme_options[custom_social_icons]', array(
		'input_attrs' => array(
            'min'   => 0,
            'max'   => 10,
            'step'  => 1,
            'style' => 'width: 45px;'
            ),
		'label'    	=> esc_html__( 'Number of Custom Social Icons', 'flat-commerce' ),
		'priority'	=> '1.5',
		'section' 	=> 'flat_commerce_custom_social_links',
		'settings'	=> 'flat_commerce_theme_options[custom_social_icons]',
		'type'		=> 'number'
		)
	);

	$priority	=	6;
	//loop for custom social icons
	for( $i = 1; $i <= $options['custom_social_icons'] ; $i++ ){
		if( $i > 9 ) // use this condition to make sure 10 comes after 9 priority wise
			$priority++;

		$wp_customize->add_setting( 'flat_commerce_theme_options[custom_social_icon_note_'. $i .']', array(
			'capability'		=> 'edit_theme_options',
			'sanitize_callback'	=> 'sanitize_text_field',
		) );

		$wp_customize->add_control( new Flat_Commerce_Note_Control( $wp_customize, 'flat_commerce_theme_options[custom_social_icon_note_'. $i .']', array(
	        'label'		=> esc_html__( 'Custom Social Icon #', 'flat-commerce' ) . $i,
			'priority'	=> $priority . '.' . $i,
	        'section'  	=> 'flat_commerce_custom_social_links',
	        'settings'	=> 'flat_commerce_theme_options[custom_social_icon_note_'. $i .']',
	        'type'     	=> 'description',
   		) ) );

   		$wp_customize->add_setting( 'flat_commerce_theme_options[custom_social_icon_title_'. $i .']', array(
			'capability'		=> 'edit_theme_options',
			'sanitize_callback'	=> 'sanitize_text_field',
		) );

		$wp_customize->add_control(  'flat_commerce_theme_options[custom_social_icon_title_'. $i .']', array(
			'label'		=> esc_html__( 'Title', 'flat-commerce' ),
			'priority'	=> $priority . '.' .$i .$i,
			'section'   => 'flat_commerce_custom_social_links',
			'settings'  => 'flat_commerce_theme_options[custom_social_icon_title_'. $i .']',
		) );

		$wp_customize->add_setting( 'flat_commerce_theme_options[custom_social_icon_image_'. $i .']', array(
			'capability'		=> 'edit_theme_options',
			'sanitize_callback'	=> 'flat_commerce_sanitize_image',
		) );

		$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'flat_commerce_theme_options[custom_social_icon_image_'. $i .']', array(
			'label'		=> esc_html__( 'Image', 'flat-commerce' ),
	        'priority'	=> $priority . '.' . $i .$i .$i,
			'section'   => 'flat_commerce_custom_social_links',
	        'settings'  => 'flat_commerce_theme_options[custom_social_icon_image_'. $i .']',
		) ) );

   		$wp_customize->add_setting( 'flat_commerce_theme_options[custom_social_icon_image_hover_'. $i .']', array(
			'capability'		=> 'edit_theme_options',
			'sanitize_callback'	=> 'flat_commerce_sanitize_image',
		) );

		$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'flat_commerce_theme_options[custom_social_icon_image_hover_'. $i .']' , array(
			'label'		=> esc_html__( 'Hover Image(Optional)', 'flat-commerce' ),
	        'priority'	=> $priority . '.' . $i .$i . $i  .$i,
			'section'   => 'flat_commerce_custom_social_links',
	        'settings'  => 'flat_commerce_theme_options[custom_social_icon_image_hover_'. $i .']',
		) ) );

		$wp_customize->add_setting( 'flat_commerce_theme_options[custom_social_icon_link_'. $i .']', array(
			'capability'		=> 'edit_theme_options',
			'sanitize_callback'	=> 'esc_url_raw',
		) );

		$wp_customize->add_control(  'flat_commerce_theme_options[custom_social_icon_link_'. $i .']', array(
			'label'		=> esc_html__( 'Link', 'flat-commerce' ),
	        'priority'	=> $priority . '.' .$i . $i  . $i  .$i .$i,
			'section'   => 'flat_commerce_custom_social_links',
	        'settings'  => 'flat_commerce_theme_options[custom_social_icon_link_'. $i .']',
		) );
	}
	// Social Icons End
