<?php
/**
 * Implement Default Theme/Customizer Options
 *
 * @package Theme Palace
 * @subpackage Flat Commerce Pro
 * @since Flat Commerce Pro 1.0
 */

if ( ! defined( 'FLAT_COMMERCE_THEME_VERSION' ) ) {
	header( 'Status: 403 Forbidden' );
	header( 'HTTP/1.1 403 Forbidden' );
	exit();
}


/**
 * Returns the default options for flat-commerce.
 *
 * @since Flat Commerce Pro 1.0
 */
function flat_commerce_get_default_theme_options() {

	$theme_data = wp_get_theme();

	$default_theme_options = array(
		//Site Title an Tagline
		'logo'                                       => get_template_directory_uri().'/images/headers/logo.png',
		'logo_alt_text'                              => '',
		'move_title_tagline'                         => 0,
		'background_color'                         	=>'#ffff',

		//Layout
		'theme_layout'                               => 'right-sidebar',
		'woocommerce_layout'                         => 'right-sidebar',
		'content_layout'                             => 'excerpt-image-top',
		'single_post_image_layout'                   => 'featured',

		//Header Image
		'enable_featured_header_image'               => 'disabled',
		'featured_header_image_position'             => 'after-menu',
		'featured_image_size'                        => 'full',
		'featured_header_image_url'                  => '',
		'featured_header_image_alt'                  => '',
		'featured_header_image_base'                 => 0,

		//Navigation
		'primary_menu_disable'                       => 0,
		'primary_search_disable'                     => 0,
		'disable_search_on_primary_menu'             => false,
		'enable_cart_on_primary_menu'                => false,
		'enable_account_on_primary_menu'             => false,
		'menu_layout_option'                         => '9',
		'primary_menu_position'						 => 'right',
		'enable_topbar'								 => true,
		'topbar_contact'							 => '123456789',
		'topbar_location'							 => esc_html__( 'Jawalakhel,Lalitpur','flat-commerce' ),
		'topbar_social_enable'					 	 => true,
		'topbar_social_media_url1'				 	 => esc_url( 'http://facebook.com' ),
		'topbar_social_media_url2'				 	 => esc_url( 'http://twitter.com' ),
		'topbar_social_media_url3'				 	 => esc_url( 'http://instagram.com' ),
		'topbar_social_media_url4'				 	 => esc_url( 'http://plus.google.com' ),
		'topbar_social_media_url5'				 	 => esc_url( 'http://pinterest.com' ),
		'topbar_social_media_icon1'			 	 	 => 'facebook-alt',
		'topbar_social_media_icon2'			 		 => 'twitter',
		'topbar_social_media_icon3'			 	 	 => 'instagram',
		'topbar_social_media_icon4'			 	 	 => 'googleplus-alt',
		'topbar_social_media_icon5'			 	 	 => 'pinterest',
		'topbar_color_layout'						 => '#b23c3c',
		'enable_frontpage_content'					 => true,

		//Breadcrumb Options
		'breadcumb_option'                           => 0,
		'breadcumb_onhomepage'                       => 0,
		'breadcumb_seperator'                        => '&raquo;',

		//Comment Options
		'disable_notes'                              => 0,
		'disable_website_field'                      => 0,

		//Custom CSS
		'custom_css'                                 => '',

		//Scrollup Options
		'disable_scrollup'                           => 0,

		//Header Right Sidebar Options
		'disable_header_right_sidebar'               => 0,

		//Excerpt Options
		'excerpt_length'                             => '55',
		'excerpt_more_text'                          => esc_html__( 'Read More ...', 'flat-commerce' ),

		//Homepage / Static Frontpage Settings
		'latest_blog_heading'                        => esc_html__( 'Latest Blog', 'flat-commerce' ),
		'front_page_category'                        => array(),

		//Pagination Options
		'pagination_type'                            => 'default',

		//Promotion Headline Options
		'promotion_headline_option'                  => 'homepage',
		'promotion_headline_left_width'              => '80',
		'promotion_headline'                         => esc_html__( 'You can edit from Appearance->Customize->Promotional Headline', 'flat-commerce' ),
		'promotion_subheadline'                      => esc_html__( 'Promotional headline', 'flat-commerce' ),
		'promotion_headline_button'                  => esc_html__( 'Buy Now', 'flat-commerce' ),
		'promotion_headline_url'                     => esc_url( 'http://themepalace.com/' ),
		'promotion_headline_target'                  => 1,

		//Responsive Options
		'footer_mobile_menu_disable'                 => 1,

		//Search Options
		'search_text'                                => esc_html__( 'Search...', 'flat-commerce' ),

		//Feed Redirect
		'feed_redirect'                              => '',

		//Single Post Navigation
		'disable_single_post_navigation'             => 0,

		//Font Family Options
		'body_font'                                  => 'nunito',
		'title_font'                                 => 'sans-serif',
		'tagline_font'                               => 'sans-serif',
		'content_title_font'                         => 'sans-serif',
		'content_font'                               => 'sans-serif',
		'headings_font'                              => 'sans-serif',
		'reset_typography'                           => 0,
		'enable_sticky_menu'						 => true,

		//Footer Editor Options
		'footer_content'                             => sprintf( _x( 'Copyright &copy; %1$s %2$s. All Rights Reserved', '1: Year, 2: Site Title with home URL', 'flat-commerce' ), '[the-year]', '[site-link]' ) . ' &#124; ' . $theme_data->get( 'Name') . __( ' by', 'flat-commerce' ). '&nbsp;<a target="_blank" href="'. esc_url( $theme_data->get( 'AuthorURI' ) ) .'">'. $theme_data->get( 'Author' ) .'</a>',
		'reset_footer_content'                       => 0,

		//Update Notifier
		'update_notifier'                            => 0,

		//Featured Product Content Options
		'featured_product_content_option'            => 'homepage',
		'featured_product_content_layout'            => 2,
		'featured_product_content_position'          => 0,
		'featured_product_content_headline'          => esc_html__( 'FEATURED THIS MONTH', 'flat-commerce' ),
		'featured_product_content_subheadline'       => 'image',
		'featured_content_subheadline'               => 'text',
		'featured_content_subheadline_text'          => '',
		'featured_product_content_url_option'        => false,
		'featured_content_subheadline_image'         => 1489,
		'featured_product_content_type'              => 'demo-featured-content',
		'featured_product_content_number'            => '3',
		'featured_content_select_category'           => array(),
		'featured_content_show'                      => 'excerpt',
		'featured_product_content_background'        => get_template_directory_uri(). '/images/gallery/featured-bg.jpg',
		'featured_product_content_subheadline_image' => get_template_directory_uri(). '/images/gallery/featured-tag.jpg',

		// Recent product content options
		'latest_blog_content_option'                 => 'disabled',
		'latest_blog_layout'                         => 3,
		'latest_blog_posts_number'                   => 3,
		'latest_blog_heading'                     => esc_html__( 'Latest Blog', 'flat-commerce' ),
		'latest_blog_content_type'                   => 'demo-latest-blog-content',
		'latest_blog_content_url_option'             => false,

		// bottom section options
		'bottom_section_design_option'                       => 'design-1',
		'bottom_section_title'                       => esc_html__( 'BOTTOM CONTENT', 'flat-commerce' ),
		'bottom_section_sub_title'                   => esc_html__( 'This is the bottom section.  You can edit by going to Appearance->Customize->Bottom Section.', 'flat-commerce' ) ,
		'bottom_section_read_more_link'              => true,
		'bottom_section_read_more_link_text'         => esc_html__( 'Read More', 'flat-commerce' ),
		'bottom_section_read_more_link_to'           => '',
		'bottom_section_social_media'                => true,
		'bottom_section_social_media_number'         => 3,
		'bottom_section_enable_option'               => 'homepage',
		'bottom_section_content_type'                => 'custom',
		'bottom_section_bg_image'					 => get_template_directory_uri(). '/images/bottom-section-bg.jpg',

		//Featured Slider Options
		'featured_slider_option'                     => 'homepage',
		'featured_slider_image_loader'               => 'true',
		'featured_slide_transition_effect'           => 'fadeout',
		'featured_slide_transition_delay'            => '4',
		'featured_slide_transition_length'           => '1',
		'featured_slide_loop'                        => 'infinite',
		'featured_slider_type'                       => 'demo-featured-slider',
		'featured_slide_number'                      => '4',
		'featured_slider_select_category'            => array(),
		'exclude_slider_post'                        => 0,
		'featured_slider_link_text'				 	 => esc_html__( 'Read More', 'flat-commerce' ),
		'featured_slider_button_color' 				 => '#b23c3c',
		'featured_slider_button_color_hover' 		 => '#862727',
		'enable_slider_captions'					 => true,
		'slider_overlay'					 		 => 0.1,


		//Product Slider Options
		'product_slider_option'                      => 'homepage',
		'product_slider_type_select'                 => 'demo-product-slider',
		'product_slider_categories_select'           => array(),
		'product_slider_no_of_tabs'                  => '3',
		'product_slider_layout_option'               => '3',
		'product_slider_no_of_products_for_category' => '6',

		//Product Slider Controls
		'product_slide_transition_effect'            => 'scrollHorz',
		'product_slide_transition_delay'             => '1',
		'product_slide_transition_length'            => '1',

		//Product Slider Banner Controls
		'product_slider_exclusive_banner_control'    => 0,
		'product_slider_exclusive_banner'            => get_template_directory_uri().'/images/gallery/exclusive.png',
		'product_slider_banner_alt_text'             => esc_html__( 'Banner Image', 'flat-commerce'),
		'product_slider_exclusive_banner_url'			=> '#',

		//Recent Products Options
		'recent_products_option'                     => 'homepage',
		'recent_products_title'                      => esc_html__( 'Recent Products', 'flat-commerce' ),
		'recent_products_title_control'              => 0,
		'recent_products_option_select'              => 'recent-product-demo',
		'recent_products_content_layout'             => '4',
		'select_recent_products_category'            => array(),
		'recent_products_visible_no'                 => '10',
		'recent_products_view_more_text'             => esc_html__('More Products', 'flat-commerce'),
		'recent_products_add_to_cart_text'           =>esc_html__('Add to Cart', 'flat-commerce'),

		//Social Links
		'social_icon_size'                           => '20',
		'custom_social_icons'                        => '1',

		// Logo Slider
		'logo_slider_enable_option'                           => 'disabled',
		'logo_slider_number'						 => 5,
			
		//Reset all settings
		'reset_all_settings'                         => 0,
	);

	return apply_filters( 'flat_commerce_default_theme_options', $default_theme_options );
}


/**
 * Returns an array of layout options registered for flat-commerce.
 *
 * @since Flat Commerce Pro 1.0
 */
function flat_commerce_layouts() {
	$layout_options = array(
		'left-sidebar' 	=> array(
			'value' => 'left-sidebar',
			'label' => esc_html__( 'Primary Sidebar, Content', 'flat-commerce' ),
		),
		'right-sidebar' => array(
			'value' => 'right-sidebar',
			'label' => esc_html__( 'Content, Primary Sidebar', 'flat-commerce' ),
		),
		'no-sidebar'	=> array(
			'value' => 'no-sidebar',
			'label' => esc_html__( 'No Sidebar ( Content Width )', 'flat-commerce' ),
		),
	);
	return apply_filters( 'flat_commerce_layouts', $layout_options );
}


/**
 * Returns an array of content layout options registered for flat-commerce.
 *
 * @since Flat Commerce Pro 1.0
 */
function flat_commerce_get_archive_content_layout() {
	$layout_options = array(
		'excerpt-image-top' => array(
			'value' => 'excerpt-image-top',
			'label' => esc_html__( 'Excerpt Image Top', 'flat-commerce' ),
		),
		'excerpt-image-right' => array(
			'value' => 'full-content-featured-image',
			'label' => esc_html__( 'Show Full Content (With Featured Image)', 'flat-commerce' ),
		),
		'full-content' => array(
			'value' => 'full-content',
			'label' => esc_html__( 'Show Full Content (No Featured Image)', 'flat-commerce' ),
		),
	);

	return apply_filters( 'flat_commerce_get_archive_content_layout', $layout_options );
}


/**
 * Returns an array of feature header enable options
 *
 * @since Flat Commerce Pro 1.0
 */
function flat_commerce_enable_featured_header_image_options() {
	$enable_featured_header_image_options = array(
		'homepage' 		=> array(
			'value'	=> 'homepage',
			'label' => esc_html__( 'Homepage / Static Frontpage', 'flat-commerce' ),
		),
		'exclude-home' 		=> array(
			'value'	=> 'exclude-home',
			'label' => esc_html__( 'Excluding Homepage', 'flat-commerce' ),
		),
		'exclude-home-page-post' 	=> array(
			'value' => 'exclude-home-page-post',
			'label' => esc_html__( 'Excluding Homepage, Page/Post Featured Image', 'flat-commerce' ),
		),
		'entire-site' 	=> array(
			'value' => 'entire-site',
			'label' => esc_html__( 'Entire Site', 'flat-commerce' ),
		),
		'entire-site-page-post' 	=> array(
			'value' => 'entire-site-page-post',
			'label' => esc_html__( 'Entire Site, Page/Post Featured Image', 'flat-commerce' ),
		),
		'pages-posts' 	=> array(
			'value' => 'pages-posts',
			'label' => esc_html__( 'Pages and Posts', 'flat-commerce' ),
		),
		'disabled'		=> array(
			'value' => 'disabled',
			'label' => esc_html__( 'Disabled', 'flat-commerce' ),
		),
	);

	return apply_filters( 'flat_commerce_enable_featured_header_image_options', $enable_featured_header_image_options );
}


/**
 * Returns an array of feature header image positions
 *
 * @since Flat Commerce Pro 1.0
 */
function flat_commerce_featured_header_image_position_options() {
	$featured_header_image_position_options = array(
		'before_menu' 		=> array(
			'value'	=> 'before-menu',
			'label' => esc_html__( 'Before Menu', 'flat-commerce' ),
		),
		'after_menu' 	=> array(
			'value' => 'after-menu',
			'label' => esc_html__( 'After Menu', 'flat-commerce' ),
		),
		'after_slider'		=> array(
			'value' => 'after-slider',
			'label' => esc_html__( 'After Slider', 'flat-commerce' ),
		),
	);

	return apply_filters( 'flat_commerce_featured_header_image_position_options', $featured_header_image_position_options );
}


/**
 * Returns an array of feature image size
 *
 * @since Flat Commerce Pro 1.0
 */
function flat_commerce_featured_image_size_options() {
	$featured_image_size_options = array(
		'full' 		=> array(
			'value'	=> 'full',
			'label' => esc_html__( 'Full Image', 'flat-commerce' ),
		),
		'large' 	=> array(
			'value' => 'large',
			'label' => esc_html__( 'Large Image', 'flat-commerce' ),
		),
		'slider'		=> array(
			'value' => 'slider',
			'label' => esc_html__( 'Slider Image', 'flat-commerce' ),
		),
	);

	return apply_filters( 'flat_commerce_featured_image_size_options', $featured_image_size_options );
}


/**
 * Returns an array of content and slider layout options registered for flat-commerce.
 *
 * @since Flat Commerce Pro 1.0
 */
function flat_commerce_featured_slider_content_options() {
	$featured_slider_content_options = array(
		'homepage' 		=> array(
			'value'	=> 'homepage',
			'label' => esc_html__( 'Homepage / Static Frontpage', 'flat-commerce' ),
		),
		'entire-site' 	=> array(
			'value' => 'entire-site',
			'label' => esc_html__( 'Entire Site', 'flat-commerce' ),
		),
		'disabled'		=> array(
			'value' => 'disabled',
			'label' => esc_html__( 'Disabled', 'flat-commerce' ),
		),
	);

	return apply_filters( 'flat_commerce_featured_slider_content_options', $featured_slider_content_options );
}


/**
 * Returns an array of feature content types registered for flat-commerce.
 *
 * @since Flat Commerce Pro 1.0
 */
function flat_commerce_featured_product_content_types() {
	$featured_content_types = array(
		'demo-featured-content' => array(
			'value' => 'demo-featured-content',
			'label' => esc_html__( 'Demo Featured Content', 'flat-commerce' ),
		),
		'featured-product-content' => array(
			'value' => 'featured-product-content',
			'label' => esc_html__( 'Featured Product Content', 'flat-commerce' ),
		),
		'featured-post-content' => array(
			'value' => 'featured-post-content',
			'label' => esc_html__( 'Featured Post Content', 'flat-commerce' ),
		),
		'featured-page-content' => array(
			'value' => 'featured-page-content',
			'label' => esc_html__( 'Featured Page Content', 'flat-commerce' ),
		),
		'featured-category-content' => array(
			'value' => 'featured-category-content',
			'label' => esc_html__( 'Featured Category Content', 'flat-commerce' ),
		),
		'featured-image-content' => array(
			'value' => 'featured-image-content',
			'label' => esc_html__( 'Featured Image Content', 'flat-commerce' ),
		),
	);

	return apply_filters( 'flat_commerce_featured_product_content_types', $featured_content_types );
}


/**
 * Returns an array of featured content options registered for flat-commerce.
 *
 * @since Flat Commerce Pro 1.0
 */
function flat_commerce_featured_product_layout_options() {
	$featured_product_layout_options = array(
		'layout-one' 		=> array(
			'value'	=> 1,
			'label' => esc_html__( '1 column', 'flat-commerce' ),
		),
		'layout-two' 		=> array(
			'value'	=> 2,
			'label' => esc_html__( '2 columns', 'flat-commerce' ),
		),
		'layout-three' 		=> array(
			'value'	=> 3,
			'label' => esc_html__( '3 columns', 'flat-commerce' ),
		),
	);

	return apply_filters( 'flat_commerce_featured_product_layout_options', $featured_product_layout_options );
}


/**
 * Returns an array of featured content show registered for flat-commerce.
 *
 * @since Flat Commerce Pro 1.0
 */
function flat_commerce_featured_content_show() {
	$featured_content_show_option = array(
		'excerpt' 		=> array(
			'value'	=> 'excerpt',
			'label' => esc_html__( 'Show Excerpt', 'flat-commerce' ),
		),
		'full-content' 	=> array(
			'value' => 'full-content',
			'label' => esc_html__( 'Show Full Content', 'flat-commerce' ),
		),
		'hide-content' 	=> array(
			'value' => 'hide-content',
			'label' => esc_html__( 'Hide Content', 'flat-commerce' ),
		),
	);

	return apply_filters( 'flat_commerce_featured_content_show', $featured_content_show_option );
}


/**
 * Returns an array of feature slider types registered for flat-commerce.
 *
 * @since Flat Commerce Pro 1.0
 */
function flat_commerce_featured_slider_types() {
	$featured_slider_types = array(
		'demo-featured-slider' => array(
			'value' => 'demo-featured-slider',
			'label' => esc_html__( 'Demo Featured Slider', 'flat-commerce' ),
		),
		'featured-post-slider' => array(
			'value' => 'featured-post-slider',
			'label' => esc_html__( 'Featured Post Slider', 'flat-commerce' ),
		),
		'featured-page-slider' => array(
			'value' => 'featured-page-slider',
			'label' => esc_html__( 'Featured Page Slider', 'flat-commerce' ),
		),
		'featured-category-slider' => array(
			'value' => 'featured-category-slider',
			'label' => esc_html__( 'Featured Category Slider', 'flat-commerce' ),
		),
		'featured-image-slider' => array(
			'value' => 'featured-image-slider',
			'label' => esc_html__( 'Featured Image Slider', 'flat-commerce' ),
		),
	);

	if ( class_exists( 'WooCommerce' ) ) {
		$featured_slider_types['featured-woo-cat'] = array(
			'value' => 'featured-woo-cat',
			'label' => esc_html__( 'Featured Product Category Slider', 'flat-commerce' ),
		);
	}

	return apply_filters( 'flat_commerce_featured_slider_types', $featured_slider_types );
}


/**
 * Returns an array of feature slider transition effects
 *
 * @since Flat Commerce Pro 1.0
 */
function flat_commerce_featured_slide_transition_effects() {
	$featured_slide_transition_effects = array(
		'fade' 		=> array(
			'value'	=> 'fade',
			'label' => esc_html__( 'Fade', 'flat-commerce' ),
		),
		'fadeout' 	=> array(
			'value'	=> 'fadeout',
			'label' => esc_html__( 'Fade Out', 'flat-commerce' ),
		),
		'none' 		=> array(
			'value' => 'none',
			'label' => esc_html__( 'None', 'flat-commerce' ),
		),
		'scrollHorz'=> array(
			'value' => 'scrollHorz',
			'label' => esc_html__( 'Scroll Horizontal', 'flat-commerce' ),
		),
		'scrollVert'=> array(
			'value' => 'scrollVert',
			'label' => esc_html__( 'Scroll Vertical', 'flat-commerce' ),
		),
		'flipHorz'	=> array(
			'value' => 'flipHorz',
			'label' => esc_html__( 'Flip Horizontal', 'flat-commerce' ),
		),
		'flipVert'	=> array(
			'value' => 'flipVert',
			'label' => esc_html__( 'Flip Vertical', 'flat-commerce' ),
		),
		'tileSlide'	=> array(
			'value' => 'tileSlide',
			'label' => esc_html__( 'Tile Slide', 'flat-commerce' ),
		),
		'tileBlind'	=> array(
			'value' => 'tileBlind',
			'label' => esc_html__( 'Tile Blind', 'flat-commerce' ),
		),
		'shuffle'	=> array(
			'value' => 'shuffle',
			'label' => esc_html__( 'Suffle', 'flat-commerce' ),
		)
	);

	return apply_filters( 'flat_commerce_featured_slide_transition_effects', $featured_slide_transition_effects );
}



/**
 * Returns an array of featured slider image loader options
 *
 * @since Flact Commerce 1.0
 */
function flat_commerce_featured_slider_image_loader() {
	$color_scheme_options = array(
		'true' => array(
			'value' 				=> 'true',
			'label' 				=> esc_html__( 'True', 'flat-commerce' ),
		),
		'wait' => array(
			'value' 				=> 'wait',
			'label' 				=> esc_html__( 'Wait', 'flat-commerce' ),
		),
		'false' => array(
			'value' 				=> 'false',
			'label' 				=> esc_html__( 'False', 'flat-commerce' ),
		),
	);

	return apply_filters( 'flat_commerce_color_schemes', $color_scheme_options );
}



/**
 * Returns an array of color schemes registered for flat-commerce.
 *
 * @since Flat Commerce Pro 1.0
 */
function flat_commerce_get_pagination_types() {
	$pagination_types = array(
		'default' => array(
			'value' => 'default',
			'label' => esc_html__( 'Default(Older Posts/Newer Posts)', 'flat-commerce' ),
		),
		'numeric' => array(
			'value' => 'numeric',
			'label' => esc_html__( 'Numeric', 'flat-commerce' ),
		),
		'infinite-scroll-click' => array(
			'value' => 'infinite-scroll-click',
			'label' => esc_html__( 'Infinite Scroll (Click)', 'flat-commerce' ),
		),
		'infinite-scroll-scroll' => array(
			'value' => 'infinite-scroll-scroll',
			'label' => esc_html__( 'Infinite Scroll (Scroll)', 'flat-commerce' ),
		),
	);

	return apply_filters( 'flat_commerce_get_pagination_types', $pagination_types );
}


/**
 * Returns an array of content featured image size.
 *
 * @since Flat Commerce Pro 1.0
 */
function flat_commerce_single_post_image_layout_options() {
	$single_post_image_layout_options = array(
		'large' => array(
			'value' => 'large',
			'label' => esc_html__( 'Large', 'flat-commerce' ),
		),
		'full-size' => array(
			'value' => 'full-size',
			'label' => esc_html__( 'Full size', 'flat-commerce' ),
		),
		'slider-image-size' => array(
			'value' => 'slider-image-size',
			'label' => esc_html__( 'Slider Image Size', 'flat-commerce' ),
		),
		'slider-image-size' => array(
			'value' => 'featured',
			'label' => esc_html__( 'Featured Image Size', 'flat-commerce' ),
		),
		'disabled' => array(
			'value' => 'disabled',
			'label' => esc_html__( 'Disabled', 'flat-commerce' ),
		),
	);
	return apply_filters( 'flat_commerce_single_post_image_layout_options', $single_post_image_layout_options );
}


/**
 * Returns an array of comment options for flat-commerce.
 *
 * @since Flat Commerce Pro 1.0
 */
function flat_commerce_comment_options() {
	$comment_options = array(
		'use-wordpress-setting' => array(
			'value' => 'use-wordpress-setting',
			'label' => esc_html__( 'Use WordPress Setting', 'flat-commerce' ),
		),
		'disable-in-pages' => array(
			'value' => 'disable-in-pages',
			'label' => esc_html__( 'Disable in Pages', 'flat-commerce' ),
		),
		'disable-completely' => array(
			'value' => 'disable-completely',
			'label' => esc_html__( 'Disable Completely', 'flat-commerce' ),
		),
	);

	return apply_filters( 'flat_commerce_comment_options', $comment_options );
}


/**
 * Returns an array of avaliable fonts registered for flat-commerce.
 *
 * @since Flat Commerce Pro 1.0
 */
function flat_commerce_avaliable_fonts() {
	$avaliable_fonts = array(
		'arial-black' => array(
			'value' => 'arial-black',
			'label' => '"Arial Black", Gadget, sans-serif',
		),
		'allan' => array(
			'value' => 'allan',
			'label' => '"Allan", sans-serif',
		),
		'allerta' => array(
			'value' => 'allerta',
			'label' => '"Allerta", sans-serif',
		),
		'amaranth' => array(
			'value' => 'amaranth',
			'label' => '"Amaranth", sans-serif',
		),
		'arial' => array(
			'value' => 'arial',
			'label' => 'Arial, Helvetica, sans-serif',
		),
		'arvo' => array(
			'value' => 'arvo',
			'label' => 'Arvo',
		),
		'bitter' => array(
			'value' => 'bitter',
			'label' => '"Bitter", sans-serif',
		),
		'cabin' => array(
			'value' => 'cabin',
			'label' => '"Cabin", sans-serif',
		),
		'cantarell' => array(
			'value' => 'cantarell',
			'label' => '"Cantarell", sans-serif',
		),
		'century-gothic' => array(
			'value' => 'century-gothic',
			'label' => '"Century Gothic", sans-serif',
		),
		'courier-new' => array(
			'value' => 'courier-new',
			'label' => '"Courier New", Courier, monospace',
		),
		'crimson-text' => array(
			'value' => 'crimson-text',
			'label' => '"Crimson Text", sans-serif',
		),
		'cuprum' => array(
			'value' => 'cuprum',
			'label' => '"Cuprum", sans-serif',
		),
		'dancing-script' => array(
			'value' => 'dancing-script',
			'label' => '"Dancing Script", sans-serif',
		),
		'droid-sans' => array(
			'value' => 'droid-sans',
			'label' => '"Droid Sans", sans-serif',
		),
		'droid-serif' => array(
			'value' => 'droid-serif',
			'label' => '"Droid Serif", sans-serif',
		),
		'exo' => array(
			'value' => 'exo',
			'label' => '"Exo", sans-serif',
		),
		'exo-2' => array(
			'value' => 'exo-2',
			'label' => '"Exo 2", sans-serif',
		),
		'georgia' => array(
			'value' => 'georgia',
			'label' => 'Georgia, "Times New Roman", Times, serif',
		),
		'helvetica' => array(
			'value' => 'helvetica',
			'label' => 'Helvetica, "Helvetica Neue", Arial, sans-serif',
		),
		'helvetica-neue' => array(
			'value' => 'helvetica-neue',
			'label' => '"Helvetica Neue",Helvetica,Arial,sans-serif',
		),
		'istok-web' => array(
			'value' => 'istok-web',
			'label' => '"Istok Web", sans-serif',
		),
		'impact' => array(
			'value' => 'impact',
			'label' => 'Impact, Charcoal, sans-serif',
		),
		'josefin-sans' => array(
			'value' => 'josefin-sans',
			'label' => '"Josefin Sans", sans-serif',
		),
		'lato' => array(
			'value' => 'lato',
			'label' => '"Lato", sans-serif',
		),
		'libre-baskerville' => array(
			'value' => 'libre-baskerville',
			'label' => '"Libre Baskerville",serif'
		),
		'lucida-sans-unicode' => array(
			'value' => 'lucida-sans-unicode',
			'label' => '"Lucida Sans Unicode", "Lucida Grande", sans-serif',
		),
		'lucida-grande' => array(
			'value' => 'lucida-grande',
			'label' => '"Lucida Grande", "Lucida Sans Unicode", sans-serif',
		),
		'lobster' => array(
			'value' => 'lobster',
			'label' => '"Lobster", sans-serif',
		),
		'lora' => array(
			'value' => 'lora',
			'label' => '"Lora", serif',
		),
		'monaco' => array(
			'value' => 'monaco',
			'label' => 'Monaco, Consolas, "Lucida Console", monospace, sans-serif',
		),
		'montserrat' => array(
			'value' => 'montserrat',
			'label' => '"Montserrat", sans-serif',
		),
		'nobile' => array(
			'value' => 'nobile',
			'label' => '"Nobile", sans-serif',
		),
		'noto-serif' => array(
			'value' => 'noto-serif',
			'label' => '"Noto Serif", serif',
		),
		'neuton' => array(
			'value' => 'neuton',
			'label' => '"Neuton", serif',
		),
		'nunito' => array(
			'value' => 'nunito',
			'label' => '"Nunito", sans-serif',
		),
		'open-sans' => array(
			'value' => 'open-sans',
			'label' => '"Open Sans", sans-serif',
		),
		'oswald' => array(
			'value' => 'oswald',
			'label' => '"Oswald", sans-serif',
		),
		'oxygen' => array(
			'value' => 'oxygen',
			'label' => '"Oxygen", sans-serif',
		),
		'palatino' => array(
			'value' => 'palatino',
			'label' => 'Palatino, "Palatino Linotype", "Book Antiqua", serif',
		),
		'patua-one' => array(
			'value' => 'patua-one',
			'label' => '"Patua One", sans-serif',
		),
		'playfair-display' => array(
			'value' => 'playfair-display',
			'label' => '"Playfair Display", sans-serif',
		),
		'pt-sans' => array(
			'value' => 'pt-sans',
			'label' => '"PT Sans", sans-serif',
		),
		'pt-serif' => array(
			'value' => 'pt-serif',
			'label' => '"PT Serif", serif',
		),
		'poppins' => array(
			'value' => 'poppins',
			'label' => '"Poppins", sans-serif',
		),
		'quattrocento-sans' => array(
			'value' => 'quattrocento-sans',
			'label' => '"Quattrocento Sans", sans-serif',
		),
		'roboto' => array(
			'value' => 'roboto',
			'label' => '"Roboto", sans-serif',
		),
		'roboto-slab' => array(
			'value' => 'roboto-slab',
			'label' => '"Roboto Slab", serif',
		),
		'sans-serif' => array(
			'value' => 'sans-serif',
			'label' => 'Sans Serif, Arial',
		),
		'source-sans-pro' => array(
			'value' => 'source-sans-pro',
			'label' => '"Source Sans Pro", sans-serif',
		),
		'tahoma' => array(
			'value' => 'tahoma',
			'label' => 'Tahoma, Geneva, sans-serif',
		),
		'trebuchet-ms' => array(
			'value' => 'trebuchet-ms',
			'label' => '"Trebuchet MS", "Helvetica", sans-serif',
		),
		'times-new-roman' => array(
			'value' => 'times-new-roman',
			'label' => '"Times New Roman", Times, serif',
		),
		'ubuntu' => array(
			'value' => 'ubuntu',
			'label' => '"Ubuntu", sans-serif',
		),
		'varela' => array(
			'value' => 'varela',
			'label' => '"Varela", sans-serif',
		),
		'verdana' => array(
			'value' => 'verdana',
			'label' => 'Verdana, Geneva, sans-serif',
		),
		'yanone-kaffeesatz' => array(
			'value' => 'yanone-kaffeesatz',
			'label' => '"Yanone Kaffeesatz", sans-serif',
		),
		'slabo' => array(
			'value' => 'slabo',
			'label' => '"Slabo", serif',
		),
	);

	return apply_filters( 'flat_commerce_avaliable_fonts', $avaliable_fonts );
}


/**
 * Returns list of social icons currently supported
 *
 * @since Flat Commerce Pro 1.0
*/
function flat_commerce_get_social_icons_list() {
	$flat_commerce_social_icons_list = array(
		'facebook_link'		=> array(
			'genericon_class' 	=> 'facebook-alt',
			'label' 			=> esc_html__( 'Facebook', 'flat-commerce' )
			),
		'twitter_link'		=> array(
			'genericon_class' 	=> 'twitter',
			'label' 			=> esc_html__( 'Twitter', 'flat-commerce' )
			),
		'googleplus_link'	=> array(
			'genericon_class' 	=> 'googleplus-alt',
			'label' 			=> esc_html__( 'Googleplus', 'flat-commerce' )
			),
		'email_link'		=> array(
			'genericon_class' 	=> 'mail',
			'label' 			=> esc_html__( 'Email', 'flat-commerce' )
			),
		'feed_link'			=> array(
			'genericon_class' 	=> 'feed',
			'label' 			=> esc_html__( 'Feed', 'flat-commerce' )
			),
		'wordpress_link'	=> array(
			'genericon_class' 	=> 'wordpress',
			'label' 			=> esc_html__( 'WordPress', 'flat-commerce' )
			),
		'github_link'		=> array(
			'genericon_class' 	=> 'github',
			'label' 			=> esc_html__( 'GitHub', 'flat-commerce' )
			),
		'linkedin_link'		=> array(
			'genericon_class' 	=> 'linkedin',
			'label' 			=> esc_html__( 'LinkedIn', 'flat-commerce' )
			),
		'pinterest_link'	=> array(
			'genericon_class' 	=> 'pinterest',
			'label' 			=> esc_html__( 'Pinterest', 'flat-commerce' )
			),
		'flickr_link'		=> array(
			'genericon_class' 	=> 'flickr',
			'label' 			=> esc_html__( 'Flickr', 'flat-commerce' )
			),
		'vimeo_link'		=> array(
			'genericon_class' 	=> 'vimeo',
			'label' 			=> esc_html__( 'Vimeo', 'flat-commerce' )
			),
		'youtube_link'		=> array(
			'genericon_class' 	=> 'youtube',
			'label' 			=> esc_html__( 'YouTube', 'flat-commerce' )
			),
		'tumblr_link'		=> array(
			'genericon_class' 	=> 'tumblr',
			'label' 			=> esc_html__( 'Tumblr', 'flat-commerce' )
			),
		'instagram_link'	=> array(
			'genericon_class' 	=> 'instagram',
			'label' 			=> esc_html__( 'Instagram', 'flat-commerce' )
			),
		'polldaddy_link'	=> array(
			'genericon_class' 	=> 'polldaddy',
			'label' 			=> esc_html__( 'PollDaddy', 'flat-commerce' )
			),
		'codepen_link'		=> array(
			'genericon_class' 	=> 'codepen',
			'label' 			=> esc_html__( 'CodePen', 'flat-commerce' )
			),
		'path_link'			=> array(
			'genericon_class' 	=> 'path',
			'label' 			=> esc_html__( 'Path', 'flat-commerce' )
			),
		'dribbble_link'		=> array(
			'genericon_class' 	=> 'dribbble',
			'label' 			=> esc_html__( 'Dribbble', 'flat-commerce' )
			),
		'skype_link'		=> array(
			'genericon_class' 	=> 'skype',
			'label' 			=> esc_html__( 'Skype', 'flat-commerce' )
			),
		'digg_link'			=> array(
			'genericon_class' 	=> 'digg',
			'label' 			=> esc_html__( 'Digg', 'flat-commerce' )
			),
		'reddit_link'		=> array(
			'genericon_class' 	=> 'reddit',
			'label' 			=> esc_html__( 'Reddit', 'flat-commerce' )
			),
		'stumbleupon_link'	=> array(
			'genericon_class' 	=> 'stumbleupon',
			'label' 			=> esc_html__( 'Stumbleupon', 'flat-commerce' )
			),
		'pocket_link'		=> array(
			'genericon_class' 	=> 'pocket',
			'label' 			=> esc_html__( 'Pocket', 'flat-commerce' ),
			),
		'dropbox_link'		=> array(
			'genericon_class' 	=> 'dropbox',
			'label' 			=> esc_html__( 'DropBox', 'flat-commerce' ),
			),
		'spotify_link'		=> array(
			'genericon_class' 	=> 'spotify',
			'label' 			=> esc_html__( 'Spotify', 'flat-commerce' ),
			),
		'foursquare_link'	=> array(
			'genericon_class' 	=> 'foursquare',
			'label' 			=> esc_html__( 'Foursquare', 'flat-commerce' ),
			),
		'twitch_link'		=> array(
			'genericon_class' 	=> 'twitch',
			'label' 			=> esc_html__( 'Twitch', 'flat-commerce' ),
			),
		'website_link'		=> array(
			'genericon_class' 	=> 'website',
			'label' 			=> esc_html__( 'Website', 'flat-commerce' ),
			),
		'phone_link'		=> array(
			'genericon_class' 	=> 'phone',
			'label' 			=> esc_html__( 'Phone', 'flat-commerce' ),
			),
		'handset_link'		=> array(
			'genericon_class' 	=> 'handset',
			'label' 			=> esc_html__( 'Handset', 'flat-commerce' ),
			),
		'cart_link'			=> array(
			'genericon_class' 	=> 'cart',
			'label' 			=> esc_html__( 'Cart', 'flat-commerce' ),
			),
		'cloud_link'		=> array(
			'genericon_class' 	=> 'cloud',
			'label' 			=> esc_html__( 'Cloud', 'flat-commerce' ),
			),
		'link_link'		=> array(
			'genericon_class' 	=> 'link',
			'label' 			=> esc_html__( 'Link', 'flat-commerce' ),
			),
	);

	return apply_filters( 'flat_commerce_social_icons_list', $flat_commerce_social_icons_list );
}


/**
 * Returns an array of metabox layout options registered for flat-commerce.
 *
 * @since Flat Commerce Pro 1.0
 */
function flat_commerce_metabox_layouts() {
	$layout_options = array(
		'default' 	=> array(
			'id' 	=> 'flat-commerce-layout-option',
			'value' => 'default',
			'label' => esc_html__( 'Default', 'flat-commerce' ),
		),
		'left-sidebar' 	=> array(
			'id' 	=> 'flat-commerce-layout-option',
			'value' => 'left-sidebar',
			'label' => esc_html__( 'Primary Sidebar, Content', 'flat-commerce' ),
		),
		'right-sidebar' => array(
			'id' 	=> 'flat-commerce-layout-option',
			'value' => 'right-sidebar',
			'label' => esc_html__( 'Content, Primary Sidebar', 'flat-commerce' ),
		),
		'no-sidebar'	=> array(
			'id' 	=> 'flat-commerce-layout-option',
			'value' => 'no-sidebar',
			'label' => esc_html__( 'No Sidebar ( Content Width )', 'flat-commerce' ),
		),
	);
	return apply_filters( 'flat_commerce_layouts', $layout_options );
}

/**
 * Returns an array of metabox header featured image options registered for flat-commerce.
 *
 * @since Flat Commerce Pro 1.0
 */
function flat_commerce_metabox_header_featured_image_options() {
	$header_featured_image_options = array(
		'default' => array(
			'id'		=> 'flat-commerce-header-image',
			'value' 	=> 'default',
			'label' 	=> esc_html__( 'Default', 'flat-commerce' ),
		),
		'enable' => array(
			'id'		=> 'flat-commerce-header-image',
			'value' 	=> 'enable',
			'label' 	=> esc_html__( 'Enable', 'flat-commerce' ),
		),
		'disable' => array(
			'id'		=> 'flat-commerce-header-image',
			'value' 	=> 'disable',
			'label' 	=> esc_html__( 'Disable', 'flat-commerce' )
		)
	);
	return apply_filters( 'header_featured_image_options', $header_featured_image_options );
}


/**
 * Returns an array of metabox sidebar options registered for flat-commerce.
 *
 * @since Flat Commerce Pro 1.0
 */
function flat_commerce_metabox_sidebar_options() {
	$sidebar_options = array(
		'main-sidebar' => array(
			'id'		=> 'flat-commerce-sidebar-options',
			'value' 	=> 'default-sidebar',
			'label' 	=> esc_html__( 'Default Sidebar', 'flat-commerce' )
		),
		'optional-sidebar-one' => array(
			'id' 	=> 'flat-commerce-sidebar-options',
			'value' => 'optional-sidebar-one',
			'label' => esc_html__( 'Optional Sidebar One', 'flat-commerce' )
		),
		'optional-sidebar-two' => array(
			'id' 	=> 'flat-commerce-sidebar-options',
			'value' => 'optional-sidebar-two',
			'label' => esc_html__( 'Optional Sidebar Two', 'flat-commerce' )
		),
		'optional-sidebar-three' => array(
			'id' 	=> 'flat-commerce-sidebar-options',
			'value' => 'optional-sidebar-three',
			'label' => esc_html__( 'Optional Sidebar three', 'flat-commerce' )
		)
	);
	return apply_filters( 'sidebar_options', $sidebar_options );
}


/**
 * Returns an array of metabox featured image options registered for flat-commerce.
 *
 * @since Flat Commerce Pro 1.0
 */
function flat_commerce_metabox_featured_image_options() {
	$featured_image_options = array(
		'default' => array(
			'id'		=> 'flat-commerce-featured-image',
			'value' 	=> 'default',
			'label' 	=> esc_html__( 'Default', 'flat-commerce' ),
		),
		'featured' => array(
			'id'		=> 'flat-commerce-featured-image',
			'value' 	=> 'featured',
			'label' 	=> esc_html__( 'Featured Image', 'flat-commerce' )
		),
		'full' => array(
			'id' => 'flat-commerce-featured-image',
			'value' => 'full',
			'label' => esc_html__( 'Full Image', 'flat-commerce' )
		),
		'slider' => array(
			'id' => 'flat-commerce-featured-image',
			'value' => 'slider',
			'label' => esc_html__( 'Slider Image', 'flat-commerce' )
		),
		'disable' => array(
			'id' => 'flat-commerce-featured-image',
			'value' => 'disable',
			'label' => esc_html__( 'Disable Image', 'flat-commerce' )
		)
	);
	return apply_filters( 'featured_image_options', $featured_image_options );
}


/**
 * Checks if there are options already present from flat-commerce free version and adds it to the flat-commerce Pro theme options
 *
 * @since Flat Commerce Pro 1.0
 * @hook after_theme_switch
 */
function flat_commerce_setup_options() {
	//Perform action only if theme_mods_flat-commerce-pro[flat_commerce_theme_options] does not exist
	if( !get_theme_mod( 'flat_commerce_theme_options' ) ) {
		//Perform action only if theme_mods_flat-commerce free version exists
		if ( $flat_commerce_free_options = get_option ( 'theme_mods_flat-commerce' ) ) {
			if ( isset( $flat_commerce_free_options['flat_commerce_theme_options'] ) ) {
				$flat_commerce_pro_default_options = flat_commerce_get_default_theme_options();

				$flat_commerce_theme_options = $flat_commerce_free_options;

				$flat_commerce_theme_options['flat_commerce_theme_options'] = array_merge( $flat_commerce_pro_default_options , $flat_commerce_free_options['flat_commerce_theme_options'] );

				update_option( 'theme_mods_flat-commerce-pro', $flat_commerce_theme_options );
			}
		}
	}
}

add_action('after_switch_theme', 'flat_commerce_setup_options');

/**
 * Returns an array of featured content options registered for flat-commerce.
 *
 * @since Flat Commerce Pro 1.0
 */
function flat_commerce_product_slider_tab_options() {
	$product_slider_tab_options = array(
		'tab-one' 		=> array(
			'value'	=> 1,
			'label' => esc_html__( '1 tab', 'flat-commerce' ),
		),
		'tab-two' 		=> array(
			'value'	=> 2,
			'label' => esc_html__( '2 tabs', 'flat-commerce' ),
		),
		'tab-three' 		=> array(
			'value'	=> 3,
			'label' => esc_html__( '3 tabs', 'flat-commerce' ),
		),
		'tab-four' 		=> array(
			'value'	=> 4,
			'label' => esc_html__( '4 tabs', 'flat-commerce' ),
		),
		'tab-five' 		=> array(
			'value'	=> 5,
			'label' => esc_html__( '5 tabs', 'flat-commerce' ),
		),
	);

	return apply_filters( 'flat_commerce_product_slider_tab_options', $product_slider_tab_options );
}


//Product Slider Options

function flat_commerce_get_product_slider_content_options() {
	/**

	* Options to display product slider in homepage or entire site or disable

	*

	* @since Flat Commerce Pro 1.0

	* @hook flat_commerce_product_slider_content_options

	*/
	$product_slider_content_options = array(
		'homepage' 		=> array(
			'value'	=> 'homepage',
			'label' => esc_html__( 'Homepage / Static Frontpage', 'flat-commerce' ),
		),
		'entire-site' 	=> array(
			'value' => 'entire-site',
			'label' => esc_html__( 'Entire Site', 'flat-commerce' ),
		),
		'disabled'		=> array(
			'value' => 'disabled',
			'label' => esc_html__( 'Disabled', 'flat-commerce' ),
		),
	);

	return apply_filters( 'flat_commerce_product_slider_content_options', $product_slider_content_options );
}

//Product Slider Type Select
function flat_commerce_get_product_slider_layout() {
	$product_slider_layout = array(
		'three-layout' => array(
			'value'	=> 3,
			'label' => esc_html__( '3 Layouts', 'flat-commerce' ),
		),
		'four-layout' => array(
			'value'	=> 4,
			'label' => esc_html__( '4 Layouts', 'flat-commerce' ),
		),
		'five-layout' => array(
			'value'	=> 5,
			'label' => esc_html__( '5 Layouts', 'flat-commerce' ),
		),
	);

	return apply_filters( 'flat_commerce_get_product_slider_layout', $product_slider_layout );
}

//Product Slider Type Select
function flat_commerce_get_product_slider_type() {
	$product_slider_type = array(
		'demo-product-slider' => array(
			'value'	=> 'demo-product-slider',
			'label' => esc_html__( 'Demo Product Slider', 'flat-commerce' ),
		),
		'category-product-slider' => array(
			'value' => 'category-product-slider',
			'label' => esc_html__( 'Category Product Slider', 'flat-commerce' ),
		),
	);

	return apply_filters( 'flat_commerce_product_slider_type', $product_slider_type );
}

//Recent Products Content Options
function flat_commerce_get_recent_products_options() {
	$recent_products_content_options = array(
		'homepage' 		=> array(
			'value'	=> 'homepage',
			'label' => esc_html__( 'Homepage / Static Frontpage', 'flat-commerce' ),
		),
		'entire-site' 	=> array(
			'value' => 'entire-site',
			'label' => esc_html__( 'Entire Site', 'flat-commerce' ),
		),
		'disabled'		=> array(
			'value' => 'disabled',
			'label' => esc_html__( 'Disabled', 'flat-commerce' ),
		),
	);

	return apply_filters( 'flat_commerce_product_slider_content_options', $recent_products_content_options );
}

// Latest Blog options
function flat_commerce_latest_blog_content_options() {
	$latest_blog_content_options = array(
		'homepage' 		=> array(
			'value'	=> 'homepage',
			'label' => esc_html__( 'Homepage / Static Frontpage', 'flat-commerce' ),
		),
		'entire-site' 	=> array(
			'value' => 'entire-site',
			'label' => esc_html__( 'Entire Site', 'flat-commerce' ),
		),
		'disabled'		=> array(
			'value' => 'disabled',
			'label' => esc_html__( 'Disabled', 'flat-commerce' ),
		),
	);

	return apply_filters( 'flat_commerce_product_slider_content_options', $latest_blog_content_options );
}

/**
 * Returns an array of latest blog content types registered for flat-commerce.
 *
 * @since Flat Commerce Pro 1.0
 */
function flat_commerce_latest_blog_content_types() {
	$latest_blog_content_types = array(
		'demo-latest-blog-content' => array(
			'value' => 'demo-latest-blog-content',
			'label' => esc_html__( 'Demo Content', 'flat-commerce' ),
		),
		'latest-blog-post-content' => array(
			'value' => 'latest-blog-post-content',
			'label' => esc_html__( 'Post Content', 'flat-commerce' ),
		),
	);

	return apply_filters( 'flat_commerce_latest_blog_content_types', $latest_blog_content_types );
}



//Product Slider Slider Type Select
function flat_commerce_get_product_slider_type_select() {
	$product_slider_type_select = array(
		'demo-product-slider' => array(
			'value'	=> 'demo-product-slider',
			'label' => esc_html__( 'Demo Product Slider', 'flat-commerce' ),
		),
		'category-product-slider' => array(
			'value' => 'category-product-slider',
			'label' => esc_html__( 'Category Product Slider', 'flat-commerce' ),
		),
	);

	return apply_filters( 'flat_commerce_product_slider_type_select', $product_slider_type_select );
}


//Recent Products Content Layout Options

function flat_commerce_get_recent_products_type_select() {

	$recent_products_type_select = array(

		'recent-product-demo' => array(

			'value'	=> 'recent-product-demo',

			'label' => esc_html__( 'Demo Recent Products', 'flat-commerce' ),

		),

		'recent-product-featured' => array(

			'value' => 'recent-product-featured',

			'label' => esc_html__( 'Featured Recent Products', 'flat-commerce' ),

		),

	);


	return apply_filters( 'flat_commerce_recent_products_type_select', $recent_products_type_select );

}

/**
 * Returns an array of featured content options registered for flat-commerce.
 *
 * @since Flat Commerce Pro 1.0
 */
function flat_commerce_recent_product_layout_options() {
	$recent_product_layout_options = array(
		'layout-one' 		=> array(
			'value'	=> 3,
			'label' => esc_html__( '3 columns', 'flat-commerce' ),
		),
		'layout-two' 		=> array(
			'value'	=> 4,
			'label' => esc_html__( '4 columns', 'flat-commerce' ),
		),
		'layout-three' 		=> array(
			'value'	=> 5,
			'label' => esc_html__( '5 columns', 'flat-commerce' ),
		),
		'layout-four' 		=> array(
			'value'	=> 6,
			'label' => esc_html__( '6 columns', 'flat-commerce' ),
		),
	);

	return apply_filters( 'flat_commerce_recent_product_layout_options', $recent_product_layout_options );
}


/** Bottom section options */
// Enable options
function flat_commerce_bottom_section_enable_options() {
	$bottom_section_enable_options = array(
		'homepage' 		=> array(
			'value'	=> 'homepage',
			'label' => esc_html__( 'Homepage / Static Frontpage', 'flat-commerce' ),
		),
		'entire-site' 	=> array(
			'value' => 'entire-site',
			'label' => esc_html__( 'Entire Site', 'flat-commerce' ),
		),
		'disabled'		=> array(
			'value' => 'disabled',
			'label' => esc_html__( 'Disabled', 'flat-commerce' ),
		),
	);

	return apply_filters( 'flat_commerce_product_slider_content_options', $bottom_section_enable_options );
}

// Content type
function flat_commerce_bottom_section_content_types() {
	$bottom_section_content_types = array(
		'custom' 		=> array(
			'value'	=> 'custom',
			'label' => esc_html__( 'Custom', 'flat-commerce' ),
		),
		'page' 	=> array(
			'value' => 'page',
			'label' => esc_html__( 'Page', 'flat-commerce' ),
		),
	);

	return apply_filters( 'flat_commerce_bottom_section_content_types', $bottom_section_content_types );
}


// pri mary menu position type
function flat_commerce_primary_menu_position_options() {
	$primary_menu_position_options = array(
		'center' 		=> array(
			'value'	=> 'center',
			'label' => esc_html__( 'Center', 'flat-commerce' ),
		),
		'right' 	=> array(
			'value' => 'right',
			'label' => esc_html__( 'Right', 'flat-commerce' ),
		),
	);

	return apply_filters( 'flat_commerce_primary_menu_position_options', $primary_menu_position_options );
}