<?php
/**
 * The template for displaying the Slider
 *
 * @package Theme Palace
 * @subpackage Flat Commerce Pro
 * @since Flat Commerce Pro 1.0
 */

if ( ! defined( 'FLAT_COMMERCE_THEME_VERSION' ) ) {
	header( 'Status: 403 Forbidden' );
	header( 'HTTP/1.1 403 Forbidden' );
	exit();
}


if( !function_exists( 'flat_commerce_featured_slider' ) ) :
/**
 * Add slider.
 *
 * @uses action hook flat_commerce_before_content.
 *
 * @since Flat Commerce Pro 1.0
 */
function flat_commerce_featured_slider() {
	global $post, $wp_query;

	//flat_commerce_flush_transients();
	// get data value from options
	$options 		= flat_commerce_get_theme_options();
	$enableslider 	= $options['featured_slider_option'];
	$sliderselect 	= $options['featured_slider_type'];
	$imageloader	= isset ( $options['featured_slider_image_loader'] ) ? $options['featured_slider_image_loader'] : 'true';

	// Get Page ID outside Loop
	$page_id = $wp_query->get_queried_object_id();

	// Front page displays in Reading Settings
	$page_on_front = get_option('page_on_front') ;
	$loop = $options['featured_slide_loop'];
	if ( $loop == 'single' ) {
		$loop_count = 1;
	} elseif ( $loop == 'infinite' ) {
		$loop_count = 0;
	}

	if ( $enableslider == 'entire-site' || ( ( $page_id == $page_on_front && $page_id > 0  ) && $enableslider == 'homepage' ) ) {
		if( ( !$flat_commerce_featured_slider = get_transient( 'flat_commerce_featured_slider' ) ) ) {
			echo '<!-- refreshing cache of featured slider -->';

			$flat_commerce_featured_slider = '
			<section id="feature-slider">
                            <div class="cycle-slideshow"
                                 data-cycle-log="false"
                                 data-cycle-swipe="true"
                                 data-cycle-fx="'.esc_html( $options['featured_slide_transition_effect'] ).'"
                                 data-cycle-speed="'. absint( $options['featured_slide_transition_length'] ) * 1000 .'"
                                 data-cycle-timeout="'. absint( $options['featured_slide_transition_delay'] ) * 1000 .'"
                                 data-cycle-loader="'. esc_attr( $imageloader ) .'"
                                 data-cycle-loop="'. esc_attr( $loop_count ) .'"
                                 data-cycle-slides="> article"
                                 data-cycle-caption=".custom-caption"
                                 data-cycle-caption-template="{{slideNum}} of {{slideCount}}"
                                 data-cycle-prev="#prev"
                                 data-cycle-next="#next">

                                 <!-- empty element for pager links -->
                                 <div class="cycle-pager"></div>

                                	<!-- prev/next links -->
                                	<div class="control-wrapper">
                                    <div class="control">
                                        <span href=# id="prev"><span class="genericon genericon-expand genericon-rotate-90"></span></span>
                                        <span href=# id="next"><span class="genericon genericon-collapse genericon-rotate-90"></span></span>
                                    </div><!-- .control -->
                                	</div><!-- .control-wrapper -->';

							// Select Slider
							if ( $sliderselect == 'demo-featured-slider' && function_exists( 'flat_commerce_demo_slider' ) ) {
								$flat_commerce_featured_slider .=  flat_commerce_demo_slider( $options );
							}
							elseif ( $sliderselect == 'featured-post-slider' && function_exists( 'flat_commerce_post_slider' ) ) {
								$flat_commerce_featured_slider .=  flat_commerce_post_slider( $options );
							}
							elseif ( $sliderselect == 'featured-page-slider' && function_exists( 'flat_commerce_page_slider' ) ) {
								$flat_commerce_featured_slider .=  flat_commerce_page_slider( $options );
							}
							elseif ( $sliderselect == 'featured-category-slider' && function_exists( 'flat_commerce_category_slider' ) ) {
								$flat_commerce_featured_slider .=  flat_commerce_category_slider( $options );
							}
							elseif ( $sliderselect == 'featured-image-slider' && function_exists( 'flat_commerce_image_slider' ) ) {
								$flat_commerce_featured_slider .=  flat_commerce_image_slider( $options );
							}
							elseif ( $sliderselect == 'featured-woo-cat' && function_exists( 'flat_commerce_product_cat_slider' ) ) {
								$flat_commerce_featured_slider .=  flat_commerce_product_cat_slider( $options );
							}

			$flat_commerce_featured_slider .= '
						</div><!-- .cycle-slideshow -->
                    </section><!-- #feature-slider -->';

			set_transient( 'flat_commerce_featured_slider', $flat_commerce_featured_slider, 86940 );
		}
		echo $flat_commerce_featured_slider;
	}
}
endif;
add_action( 'flat_commerce_before_content', 'flat_commerce_featured_slider', 20 );


if ( ! function_exists( 'flat_commerce_demo_slider' ) ) :
/**
 * This function to display featured posts slider
 *
 * @get the data value from customizer options
 *
 * @since Flat Commerce Pro 1.0
 *
 */
function flat_commerce_demo_slider( $options ) {
	$flat_commerce_demo_slider ='
		<article class="slides display-block">
			<div class="black-overlay"></div>
            <figure class="slider-image">
                <a title="'. esc_attr__( 'slider image 1','flat-commerce' ) .'" href="'.esc_url( home_url( '/' ) ).'">
                    <img src="'.get_template_directory_uri().'/images/gallery/banner1.jpg" width="1800" height="720" alt="'. esc_attr__( 'Banner','flat-commerce' ) .'"/>
                </a>
            </figure>
            <div class="entry-container">
                <header class="entry-header">
                    <h1 class="entry-title">
                    	<p><img src="'. get_template_directory_uri() . '/images/slider-logo-01.png" alt="'. esc_attr__( 'logo','flat-commerce' ) .'"></p>
                        <span>'.esc_html__( 'Wear It Once In a Lifetime', 'flat-commerce' ).'</span>
                        <a title="'. esc_attr__( 'slider image 1','flat-commerce' ) .'" href="#">'.esc_html__( 'vine clothing', 'flat-commerce' ).'</a>
                    </h1>
                </header><!-- .entry-header -->
                <a href="#" class="read-more">'
                    .esc_html__( 'Shop Now', 'flat-commerce' ).'
                </a>
            </div><!-- .entry-container -->
        </article><!-- .slides -->

        <article class="slides display-none">
			<div class="black-overlay"></div>
            <figure class="slider-image">
                <a title="'. esc_attr__( 'slider image 2','flat-commerce' ) .'" href="'.esc_url( home_url( '/' ) ).'">
                    <img src="'.get_template_directory_uri().'/images/gallery/banner2.jpg" width="1800" height="720" alt="'. esc_attr__( 'Banner','flat-commerce' ) .'"/>
                </a>
            </figure>
            <div class="entry-container">
                <header class="entry-header">
                    <h1 class="entry-title">
                    	<p><img src="'. get_template_directory_uri() . '/images/slider-logo-01.png" alt="'. esc_attr__( 'logo','flat-commerce' ) .'"></p>
                        <span>'. esc_html__( 'Wear It Once In a Lifetime', 'flat-commerce') .'</span>
                        <a title="'. esc_attr__( 'slider image 2','flat-commerce' ) .'" href="#">'.esc_html__( 'vine clothing', 'flat-commerce' ).'</a>
                    </h1>
                </header><!-- .entry-header -->
                <a href="#" class="read-more">'.
                   esc_html__( 'Shop Now', 'flat-commerce' )
                    .'</a>
            </div> <!-- .entry-container -->
        </article><!-- .slides --> ';
return $flat_commerce_demo_slider;
}
endif; // flat_commerce_demo_slider


if ( ! function_exists( 'flat_commerce_post_slider' ) ) :
/**
 * This function to display featured posts slider
 *
 * @param $options: flat_commerce_theme_options from customizer
 *
 * @since Flat Commerce Pro 1.0
 */
function flat_commerce_post_slider( $options ) {
	$quantity	= $options['featured_slide_number'];

	global $post;

	$flat_commerce_post_slider = '';
	$number_of_post            = 0; // for number of posts
	$post_list                 = array();	// list of valid post ids

	//Get valid post ids
	for( $i = 1; $i <= $quantity; $i++ ){
		if( isset ( $options['featured_slider_post_' . $i] ) && $options['featured_slider_post_' . $i] > 0 ){
			$number_of_post++;

			$post_list	=	array_merge( $post_list, array( $options['featured_slider_post_' . $i] ) );
		}

	}

	if ( !empty( $post_list ) && $number_of_post > 0 ) {
        $flat_commerce_post_slider = '';

    	$get_featured_posts = new WP_Query( array(
			'posts_per_page'      => $number_of_post,
			'post__in'            => $post_list,
			'orderby'             => 'post__in',
			'ignore_sticky_posts' => 1 // ignore sticky posts
        ));

		$i=0;
		while ( $get_featured_posts->have_posts() ) : $get_featured_posts->the_post(); $i++;
			$class = ( 0 == $i ) ? 'display-block' : 'display-none' ;
			$title_attribute = the_title_attribute( array( 'before' => __( 'Permalink to: ', 'flat-commerce' ), 'echo' => false ) );
			$excerpt = get_the_excerpt();
			$slider_logo = ! empty( $options['featured_slider_logo_' . $i] ) ? '<p><img src="'. esc_url( $options['featured_slider_logo_' . $i] ).'"></p>' : '';

			$flat_commerce_post_slider .= '
			<article class="slides ' . esc_attr( $class ).'">
				<div class="black-overlay"></div>
				<figure class="slider-image">';
				if ( has_post_thumbnail() ) {
					$flat_commerce_post_slider .= '<a title="'.the_title_attribute( array( 'before' => __( 'Permalink to: ', 'flat-commerce' ), 'echo' => false ) ).'" href="' . esc_url( get_permalink() ) . '">
						'. get_the_post_thumbnail( $post->ID, 'flat-commerce-slider', array( 'title' => esc_attr( $title_attribute ), 'alt' => esc_attr( $title_attribute ) ) ).'
					</a>';
				}
				else {
					//Default value if there is no first image
					$flat_commerce_image = '<img class="pngfix wp-post-image" src="'.get_template_directory_uri().'/images/gallery/no-featured-image-1366x585.png" >';

					//Get the first image in page, returns false if there is no image
					$flat_commerce_first_image = flat_commerce_get_first_image( $post->ID, 'flat-commerce-slider', array( 'title' => esc_attr( $title_attribute ), 'alt' => esc_attr( $title_attribute ), 'class' => 'attached-post-image' ) );

					//Set value of image as first image if there is an image present in the page
					if ( '' != $flat_commerce_first_image ) {
						$flat_commerce_image =	$flat_commerce_first_image;
					}

					$flat_commerce_post_slider .= '<a title="'. the_title_attribute( array( 'before' => __( 'Permalink to: ', 'flat-commerce' ), 'echo' => false ) ) .'" href="' . esc_url( get_permalink() ) . '">
						'. $flat_commerce_image .'
					</a>';
				}

				$flat_commerce_post_slider .= '
				</figure><!-- .slider-image -->';
				if( true === $options['enable_slider_captions'] ) {
					$flat_commerce_post_slider .= '<div class="entry-container">
					<header class="entry-header">
                        <h1 class="entry-title">
                        '. $slider_logo .'
							<a title="'. the_title_attribute( array( 'before' => __( 'Permalink to: ', 'flat-commerce' ), 'echo' => false ) ) .'" href="' . esc_url( get_permalink() ) . '">'.esc_html( get_the_title() ).'</a>
						</h1>
					</header><!-- .entry-header -->';
					$link_text =  !empty( $options['featured_slider_link_text'] ) ? $options['featured_slider_link_text'] : '';
					if( !empty( $link_text ) ){
						$flat_commerce_post_slider .= '<a href="'.esc_url( get_permalink() ).'" class="read-more">'. esc_html( $link_text ) .' </a>';
					}

					$flat_commerce_post_slider .= '
					</div><!-- .entry-container -->';
				}
			$flat_commerce_post_slider .= '</article><!-- .slides -->';
		endwhile;

		wp_reset_query();

		return $flat_commerce_post_slider;
	}
}
endif; // flat_commerce_post_slider


if ( ! function_exists( 'flat_commerce_page_slider' ) ) :
/**
 * This function to display featured page slider
 *
 * @param $options: flat_commerce_theme_options from customizer
 *
 * @since Flat Commerce Pro 1.0
 */
function flat_commerce_page_slider( $options ) {
    global $post;

	$quantity                  = $options['featured_slide_number'];
	$more_link_text            = $options['excerpt_more_text'];
	$number_of_page            = 0; 		// for number of pages
	$page_list                 = array();	// list of valid page ids
	$flat_commerce_page_slider = '';  //set empty value

	//Get number of valid pages
	for( $i = 1; $i <= $quantity; $i++ ){
		if( isset ( $options['featured_slider_page_' . $i] ) && $options['featured_slider_page_' . $i] > 0 ){
			$number_of_page++;

			$page_list	=	array_merge( $page_list, array( $options['featured_slider_page_' . $i] ) );
		}
	}

	if ( !empty( $page_list ) && $number_of_page > 0 ) {
		$get_featured_posts = new WP_Query( array(
		'posts_per_page'	=> $quantity,
		'post_type'			=> 'page',
		'post__in'			=> $page_list,
		'orderby' 			=> 'post__in'
		));

		$i = 0;

		while ( $get_featured_posts->have_posts()) : $get_featured_posts->the_post(); $i++;
			$class = ( 0 == $i ) ? 'display-block' : 'display-none' ;
			$title_attribute = the_title_attribute( array( 'before' => __( 'Permalink to: ', 'flat-commerce' ), 'echo' => false ) );
			$excerpt = get_the_excerpt();
			$slider_logo = ! empty( $options['featured_slider_logo_' . $i] ) ? '<p><img src="'. esc_url( $options['featured_slider_logo_' . $i] ).'"></p>' : '';

			$flat_commerce_page_slider .= '
			<article class="slides ' . esc_attr( $class ).'">
				<div class="black-overlay"></div>
				<figure class="slider-image">';
				if ( has_post_thumbnail() ) {
					$flat_commerce_page_slider .= '<a title="'. the_title_attribute( array( 'before' => __( 'Permalink to: ', 'flat-commerce' ), 'echo' => false ) ) .'" href="' . esc_url( get_permalink() ) . '">
						'. get_the_post_thumbnail( $post->ID, 'flat-commerce-slider', array( 'title' => esc_attr( $title_attribute ), 'alt' => esc_attr( $title_attribute ), 'class'	=> 'attached-page-image' ) ).'
					</a>';
				}
				else {
					//Default value if there is no first image
					$flat_commerce_image = '<img class="pngfix wp-post-image" src="'.get_template_directory_uri().'/images/gallery/no-featured-image-1366x585.png" >';

					//Get the first image in page, returns false if there is no image
					$flat_commerce_first_image = flat_commerce_get_first_image( $post->ID, 'flat-commerce-slider', array( 'title' => esc_attr( $title_attribute ), 'alt' => esc_attr( $title_attribute ), 'class' => 'attached-page-image' ) );

					//Set value of image as first image if there is an image present in the page
					if ( '' != $flat_commerce_first_image ) {
						$flat_commerce_image =	$flat_commerce_first_image;
					}

					$flat_commerce_page_slider .= '<a title="'. the_title_attribute( array( 'before' => __( 'Permalink to: ', 'flat-commerce' ), 'echo' => false ) ) .'" href="' . esc_url(  get_permalink() ) . '">
						'. $flat_commerce_image .'
					</a>';
				}

				$flat_commerce_page_slider .= '
				</figure><!-- .slider-image -->';
				if( true === $options['enable_slider_captions'] ) {
					$flat_commerce_page_slider .= '<div class="entry-container">
					<header class="entry-header">
						<h1 class="entry-title">
						'. $slider_logo .'
							<a title="'. the_title_attribute( array( 'before' => __( 'Permalink to: ', 'flat-commerce' ), 'echo' => false ) ) .'" href="' . esc_url( get_permalink() ) . '">'.esc_html( get_the_title() ).'
							</a>
						</h1>
					</header><!-- .entry-header -->';

					$link_text =  !empty( $options['featured_slider_link_text'] ) ? $options['featured_slider_link_text'] : '';
					if( !empty( $link_text ) ){
						$flat_commerce_page_slider .= '<a href="'.esc_url( get_permalink() ).'" class="read-more">'. esc_html( $link_text ) .' </a>';
					}

						$flat_commerce_page_slider .= '
					</div><!-- .entry-container -->';
				}
			$flat_commerce_page_slider .= '</article><!-- .slides -->';
		endwhile;

		wp_reset_query();
  	}
	return $flat_commerce_page_slider;
}
endif; // flat_commerce_page_slider


if ( ! function_exists( 'flat_commerce_category_slider' ) ) :
/**
 * This function to display featured category slider
 *
 * @param $options: flat_commerce_theme_options from customizer
 *
 * @since Flat Commerce Pro 1.0
 */
function flat_commerce_category_slider( $options ) {
	global $post;

    $quantity	= $options['featured_slide_number'];

	$flat_commerce_category_slider = '';

	$category_list	= array_filter( (array)$options['featured_slider_select_category'] );

	if ( !empty( $category_list ) ) {
		$get_featured_posts = new WP_Query( array(
			'posts_per_page'		=> $quantity,
			'category__in'			=> $category_list,
			'ignore_sticky_posts' 	=> 1 // ignore sticky posts
		));

		$i=0;

		while ( $get_featured_posts->have_posts()) : $get_featured_posts->the_post(); $i++;
			$class = ( 0 == $i ) ? 'display-block' : 'display-none' ;
			$title_attribute = the_title_attribute( array( 'before' => __( 'Permalink to: ', 'flat-commerce' ), 'echo' => false ) );
			$excerpt = get_the_excerpt();

			$flat_commerce_category_slider .= '
			<article class="slides ' . esc_attr( $class ).'">
				<div class="black-overlay"></div>
				<figure class="slider-image">';
				if ( has_post_thumbnail() ) {
					$flat_commerce_category_slider .= '<a title="Permalink to '.the_title('','',false).'" href="' . esc_url( get_permalink() ) . '">
						'. get_the_post_thumbnail( $post->ID, 'flat-commerce-slider', array( 'title' => esc_attr( $title_attribute ), 'alt' => esc_attr( $title_attribute ), 'class'	=> 'attached-post-image' ) ).'
					</a>';
				}
				else {
					//Default value if there is no first image
					$flat_commerce_image = '<img class="pngfix wp-post-image" src="'.get_template_directory_uri().'/images/gallery/slider2-1200x514.jpg" >';

					//Get the first image in page, returns false if there is no image
					$flat_commerce_first_image = flat_commerce_get_first_image( $post->ID, 'flat-commerce-slider', array( 'title' => esc_attr( $title_attribute ), 'alt' => esc_attr( $title_attribute ), 'class' => 'attached-post-image' ) );
					//Set value of image as first image if there is an image present in the page
					if ( '' != $flat_commerce_first_image ) {
						$flat_commerce_image =	$flat_commerce_first_image;
					}

					$flat_commerce_category_slider .= '<a title="'. the_title_attribute( array( 'before' => __( 'Permalink to: ', 'flat-commerce' ), 'echo' => false ) ) .'" href="' . esc_url( get_permalink() ) . '">
						'. $flat_commerce_image .'
					</a>';
				}


				$flat_commerce_category_slider .= '
				</figure><!-- .slider-image -->';
				if( true === $options['enable_slider_captions'] ) {
					$flat_commerce_category_slider .= '<div class="entry-container">
					<header class="entry-header">
						<h1 class="entry-title">
							<a title="'. the_title_attribute( array( 'before' => __( 'Permalink to: ', 'flat-commerce' ), 'echo' => false ) ) .'" href="' . esc_url( get_permalink() ) . '">'.esc_html( get_the_title() ).'</a>
						</h1>
					</header>';

					$link_text =  !empty( $options['featured_slider_link_text'] ) ? $options['featured_slider_link_text'] : '';
					if( !empty( $link_text ) ){
						$flat_commerce_category_slider .= '<a href="'.esc_url( get_permalink() ).'" class="read-more">'. esc_html( $link_text ) .' </a>';
					}

						$flat_commerce_category_slider .= '
					</div><!-- .entry-container -->';
				}
			$flat_commerce_category_slider .= '</article><!-- .slides -->';
		endwhile;

		wp_reset_query();
	}
	return $flat_commerce_category_slider;
}
endif; // flat_commerce_category_slider


if ( ! function_exists( 'flat_commerce_image_slider' ) ) :
/**
 * This function to display featured posts slider
 *
 * @get the data value from theme options
 * @displays on the index
 *
 * @useage Featured Image, Title and Excerpt of Post
 *
 */
function flat_commerce_image_slider( $options ) {
	$quantity	= $options['featured_slide_number'];

	$flat_commerce_image_slider = '';

	for ( $i = 1; $i <= $quantity; $i++ ) {

		//Adding in Classes for Display block and none
		if ( $i == 1 ) { $classes = 'slider-image images-'.$i.' hentry slides display-block'; } else { $classes = 'slider-image images-'.$i.' hentry slides display-none'; }

		//Check Image Not Empty to add in the slides
		if ( !empty ( $options[ 'featured_slider_image_'. $i ] ) ) {

			$slider_logo = ! empty( $options['featured_slider_image_logo_' . $i] ) ? '<p><img src="'. esc_url( $options['featured_slider_image_logo_' . $i] ).'"></p>' : '';
			//Checking Title
			if ( !empty ( $options[ 'featured_title_'. $i ] ) ) {
				$imagetitle = $options[ 'featured_title_'. $i ];
			}
			else {
				$imagetitle = 'Featured Image-'.$i;
			}

			//Checking Link
			if ( !empty ( $options[ 'featured_link_'. $i ] ) ) {
				$link = $options[ 'featured_link_'. $i ];

				//Checking Link Target
				if ( !empty ( $options[ 'featured_target_'. $i ] ) ) {
					$target = '_blank';
				} else {
					$target = '_self';
				}

				//Checking image
				$image = '<a href="'. esc_url( $link ).'" title="'. esc_attr( $imagetitle ) .'" target="'.$target.'"><img alt="'. esc_attr( $imagetitle ) .'" class="wp-post-image" src="'. esc_url( $options[ 'featured_slider_image_'. $i ] ) .'" /></a>';

			}
			else {
				$link = '';
				$target = '';
				$image = '<img alt="'. esc_attr( $imagetitle ) .'" class="wp-post-image" src="'. esc_url( $options['featured_slider_image_'. $i] ).'" />';
			}

			//Checking Title
			if ( !empty ( $options['featured_title_'. $i] ) ) {
				$content_title = $options['featured_title_'. $i];

				if ( !empty ( $options[ 'featured_link_'. $i ] ) ) {
					$title = '<header class="entry-header"><h1 class="entry-title">'. $slider_logo .'<a title="' . esc_attr( $content_title ) . '" href="' . esc_url( $link ) . '" target="' . $target . '"><span>' . esc_attr( $content_title ) . '</span></a></h1></header>';
				}
				else {
					$title = '<header class="entry-header"><h1 class="entry-title">'. $slider_logo .'<span>' . esc_attr( $content_title ) . '</span></h1></header>';
				}

			}
			else {
				$content_title = '';
				$title = '';
			}

			//Checking Content
			if ( !empty ( $options['featured_content_'. $i] ) ) {
				$content = '<div class="entry-content"><p>' . $options['featured_content_'. $i] . '</p></div><!-- .entry-content -->';
			}
			else {
				$content = '';
			}

			//Content Opening and Closing
			if ( !empty ( $content_title ) || !empty ( $content ) ) {
				$contentopening = '<div class="entry-container"><p>';
				$contentclosing = '</p></div>';
			}
			else {
				$contentopening = '';
				$contentclosing = '';
			}

			$flat_commerce_image_slider .= '
								<article class="image-slides hentry '. $classes .'">
									<div class="black-overlay"></div>
									<figure class="slider-image">
										'. $image .'
									</figure>';
		    if( true === $options['enable_slider_captions'] ) {
				$flat_commerce_image_slider .= $contentopening . $title . $content . $contentclosing;
			}
			$flat_commerce_image_slider .= '</article><!-- .slides --> ';
		}
	}
	return $flat_commerce_image_slider;
}
endif; //flat_commerce_image_slider

if ( ! function_exists( 'flat_commerce_product_cat_slider' ) ) :
/**
 * This function to display featured product category slider
 *
 * @get the data value from theme options
 * @displays on the index
 *
 * @useage Featured Image, Title and Excerpt of Post
 *
 */
function flat_commerce_product_cat_slider( $options ) {
	$quantity	= $options['featured_slide_number'];

	$flat_commerce_product_cat_slider = '';

	$category_list = [];
	for ( $i = 1; $i < $quantity; $i++ ) { 
		if ( isset( $options['featured_product_slider_'.$i] ) && ! empty( $options['featured_product_slider_'.$i] ) ) {
			$woo_cat_id = (int)$options['featured_product_slider_'.$i];
			$woo_cat = get_term( (int)$woo_cat_id );
			$title_attribute = $woo_cat->name;
			$thumbnail_id = get_woocommerce_term_meta( $woo_cat_id, 'thumbnail_id', true );
			$image = '';
			if ( $thumbnail_id ) {
				$image = '<img src="' . wp_get_attachment_url( $thumbnail_id ) . '" alt="' . $title_attribute . '" class="attached-post-image" />';
			}

			$flat_commerce_product_cat_slider .= '
			<article class="slides">
				<div class="black-overlay"></div>
				<figure class="slider-image">';
				if ( $image ) {
					$flat_commerce_product_cat_slider .= '<a title="Permalink to '.$title_attribute.'" href="' . esc_url( get_term_link( $woo_cat_id ) ) . '">
						'. $image .'
					</a>';
				}
				else {
					//Default value if there is no first image
					$flat_commerce_image = '<img class="pngfix wp-post-image" src="'.get_template_directory_uri().'/images/gallery/slider2-1200x514.jpg" >';

					$flat_commerce_product_cat_slider .= '<a title="'. $title_attribute .'" href="' . esc_url( get_term_link( $woo_cat_id ) ) . '">
						'. $flat_commerce_image .'
					</a>';
				}


				$flat_commerce_product_cat_slider .= '
				</figure><!-- .slider-image -->';
				if( true === $options['enable_slider_captions'] ) {
					$flat_commerce_product_cat_slider .= '<div class="entry-container">
					<header class="entry-header">
						<h1 class="entry-title">
							<a title="'. $title_attribute .'" href="' . esc_url( get_term_link( $woo_cat_id ) ) . '">'.esc_html( $title_attribute ).'</a>
						</h1>
					</header>';

					$link_text =  !empty( $options['featured_slider_link_text'] ) ? $options['featured_slider_link_text'] : '';
					if( !empty( $link_text ) ){
						$flat_commerce_product_cat_slider .= '<a href="'.esc_url( get_term_link( $woo_cat_id ) ).'" class="read-more">'. esc_html( $link_text ) .' </a>';
					}

						$flat_commerce_product_cat_slider .= '
					</div><!-- .entry-container -->';
				}
			$flat_commerce_product_cat_slider .= '</article><!-- .slides -->';
		}
	}

	return $flat_commerce_product_cat_slider;
}
endif; //flat_commerce_product_cat_slider