<?php
/**
 * The template for adding Contact Fields widget
 *
 * @package Theme Palace
 * @subpackage Flat Commerce Pro
 * @since Flat Commerce Pro 1.0
 */

if ( ! defined( 'FLAT_COMMERCE_THEME_VERSION' ) ) {
	header( 'Status: 403 Forbidden' );
	header( 'HTTP/1.1 403 Forbidden' );
	exit();
}

/**
 * Core class used to implement a Text widget.
 *
 *
 * @see WP_Widget
 */
class Flat_Commerce_Widget_Contact_Fields extends WP_Widget {

	/**
	 * Sets up a new Contact widget instance.
	 *
	 * @access public
	 */
	public function __construct() {
		$widget_ops = array('classname' => 'widget_text', 'description' => __( 'Widget for additonal fields.', 'flat-commerce' ));
		$control_ops = array('width' => 400, 'height' => 350);
		parent::__construct('contact_additonal_fields', __('TP: Contact Additional Fields', 'flat-commerce' ), $widget_ops, $control_ops);
	}

	/**
	 * Outputs the content for the current Text widget instance.
	 *
	 * @access public
	 *
	 * @param array $args     Display arguments including 'before_title', 'after_title',
	 *                        'before_widget', and 'after_widget'.
	 * @param array $instance Settings for the current Text widget instance.
	 */
	public function widget( $args, $instance ) {

		/** This filter is documented in wp-includes/widgets/class-wp-widget-pages.php */
		$title = apply_filters( 'widget_title', empty( $instance['title'] ) ? '' : $instance['title'], $instance, $this->id_base );

		$widget_text = ! empty( $instance['text'] ) ? $instance['text'] : '';

		$icon = ! empty( $instance['icon'] ) ? $instance['icon'] : '';

		/**
		 * Filter the content of the Text widget.
		 *
		 * @param string         $widget_text The widget content.
		 * @param array          $instance    Array of settings for the current widget.
		 * @param WP_Widget_Text $this        Current Text widget instance.
		 */
		$text = apply_filters( 'widget_text', $widget_text, $instance, $this );

		echo $args['before_widget']; ?>

			<!-- <div class="col col-1-of-4"> -->
				<?php
				if ( ! empty( $title ) ) {
					echo  $args['before_title'].'<span class="genericon genericon-'.$icon.'">' . $title . '</span>' .  $args['after_title'];
				} ?>

			    <span><?php echo !empty( $instance['filter'] ) ? wpautop( $text ) : $text; ?></span>

			<!-- </div> --><!-- .col -->

		<?php
		echo $args['after_widget'];
	}

	/**
	 * Handles updating settings for the current Text widget instance.
	 *
	 * @access public
	 *
	 * @param array $new_instance New settings for this instance as input by the user via
	 *                            WP_Widget::form().
	 * @param array $old_instance Old settings for this instance.
	 * @return array Settings to save or bool false to cancel saving.
	 */
	public function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = sanitize_text_field( $new_instance['title'] );
		if ( current_user_can('unfiltered_html') )
			$instance['text'] =  $new_instance['text'];
		else
			$instance['text'] = wp_kses_post( stripslashes( $new_instance['text'] ) );
		$instance['filter'] = ! empty( $new_instance['filter'] );

		$instance['icon'] = $new_instance['icon'];

		return $instance;
	}

	/**
	 * Outputs the Text widget settings form.
	 *
	 * @access public
	 *
	 * @param array $instance Current settings.
	 */
	public function form( $instance ) {
		$instance = wp_parse_args( (array) $instance, array( 'title' => '', 'text' => '', 'icon' => '' ) );
		$filter = isset( $instance['filter'] ) ? $instance['filter'] : 0;
		$title = sanitize_text_field( $instance['title'] );
		$icon = isset( $instance['icon'] ) ? $instance['icon'] : 0;
		?>
		<p><label for="<?php echo esc_attr( $this->get_field_id('title') ); ?>"><?php _e( 'Field Title:', 'flat-commerce' ); ?></label>
		<input class="widefat" id="<?php echo esc_attr( $this->get_field_id('title') ); ?>" name="<?php echo esc_attr( $this->get_field_name('title') ); ?>" type="text" value="<?php echo esc_attr($title); ?>" /></p>

		<p><label for="<?php echo esc_attr( $this->get_field_id( 'text' ) ); ?>"><?php _e( 'Field Information:', 'flat-commerce' ); ?></label>
		<textarea class="widefat" rows="16" cols="20" id="<?php echo esc_attr( $this->get_field_id('text') ); ?>" name="<?php echo esc_attr( $this->get_field_name('text') ); ?>"><?php echo esc_textarea( $instance['text'] ); ?></textarea></p>

		<p><label for="<?php echo esc_attr( $this->get_field_id( 'show_content' ) ); ?>"><?php _e( 'Select Icon', 'flat-commerce' ); ?>:</label>


		<select id="<?php echo esc_attr( $this->get_field_id( 'icon' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'icon' ) ); ?>">
				<?php
				$flat_commerce_contact_info_icons = flat_commerce_get_social_icons_list();
			    foreach ( $flat_commerce_contact_info_icons as $flat_commerce_contact_info_icons ) { ?>
					<option value="<?php echo $flat_commerce_contact_info_icons['genericon_class']; ?>" <?php selected( $flat_commerce_contact_info_icons['genericon_class'], $instance['icon'] ); ?>><?php echo $flat_commerce_contact_info_icons['label']; ?></option>
			    <?php } ?>
		</select></p>

		<p><input id="<?php echo esc_attr( $this->get_field_id('filter') ); ?>" name="<?php echo esc_attr( $this->get_field_name('filter'), 'flat-commerce' ); ?>" type="checkbox"<?php checked( $filter ); ?> />&nbsp;<label for="<?php echo esc_attr( $this->get_field_id('filter') ); ?>"><?php _e('Automatically add paragraphs', 'flat-commerce' ); ?></label></p>

		<?php
	}
}
