<?php
/**
 * The template for adding Image widget
 *
 * @package Theme Palace
 * @subpackage Flat Commerce Pro
 * @since Flat Commerce Pro 1.0
 */

if ( ! defined( 'FLAT_COMMERCE_THEME_VERSION' ) ) {
	header( 'Status: 403 Forbidden' );
	header( 'HTTP/1.1 403 Forbidden' );
	exit();
}


/**
 * Adds image widget.
 */
class Flatcommerce_image_widget extends WP_Widget {

	/**
	 * Register widget with WordPress.
	 */
	function __construct() {
		parent::__construct(
			'tp_image_widget', // Base ID
			__( 'TP: Featured Image Widget', 'flat-commerce' ), // Name
			array( 'description' => __( 'An widget to upload featured images in sidebar.', 'flat-commerce' ), ) // Args
		);
	}

	/**
	 * Front-end display of widget.
	 *
	 * @see WP_Widget::widget()
	 *
	 * @param array $args     Widget arguments.
	 * @param array $instance Saved values from database.
	 */
	public function widget( $args, $instance ) {
		extract( $args , EXTR_SKIP );

			$title                      = apply_filters( 'widget_title', empty( $instance['title'] ) ? '' : $instance['title'], $instance, $this->id_base );
			$subtitle 					= ! empty( $instance['subtitle'] ) ? $instance['subtitle'] : '' ;
			$tpiw_image_url             = ! empty( $instance['tpiw_image_url'] ) ? $instance['tpiw_image_url'] : '';
			$tpiw_image_width           = ! empty( $instance['tpiw_image_width'] ) ? $instance['tpiw_image_width'] : '';
			$tpiw_image_height          = ! empty( $instance['tpiw_image_height'] ) ? $instance['tpiw_image_height'] : '';
			$tpiw_link                  = ! empty( $instance['tpiw_link'] ) ? $instance['tpiw_link'] : '';
			$tpiw_alt_text              = ! empty( $instance['tpiw_alt_text'] ) ? $instance['tpiw_alt_text'] : '';
			$tpiw_open_link             = ! empty( $instance['tpiw_open_link'] ) ? $instance['tpiw_open_link'] : false;
			$tpiw_image_caption         = ! empty( $instance['tpiw_image_caption'] ) ? $instance['tpiw_image_caption'] : '';
			$tpiw_disable_link_in_title = ! empty( $instance['tpiw_disable_link_in_title'] ) ? $instance['tpiw_disable_link_in_title'] : false;
			$tpiw_show_button           = ! empty( $instance['tpiw_show_button'] ) ? $instance['tpiw_show_button'] : false;
			$tpiw_button_text           = ! empty( $instance['tpiw_button_text'] ) ? $instance['tpiw_button_text'] : '';

			$instance['link_open'] = '';
			$instance['link_close'] = '';

        if ( ! empty ( $tpiw_link ) ) {

          $target                 = ( empty( $tpiw_open_link ) ) ? '' : ' target="_blank" ';
          $instance['link_open']  = '<a href="' . esc_url( $tpiw_link ) . '"' . $target . '>';
          $instance['link_close'] = '</a>';

        }
		echo $args['before_widget'];

        if (!empty( $tpiw_image_url)) {

          $sizes = array();

          $alt_text = ( ! empty( $tpiw_alt_text ) ) ? $tpiw_alt_text : basename( $tpiw_image_url );
          $dimension_text = '';

          if ( ! empty( $tpiw_image_width ) ) {

            $dimension_text .= ' width="' . esc_attr( $tpiw_image_width ) . '" ';

          }

          if ( ! empty( $tpiw_image_height ) ) {

            $dimension_text .= ' height="' . esc_attr( $tpiw_image_height ) . '" ';

          }

          $imgtag = '<img src="' . esc_url( $tpiw_image_url ) . '" alt="' . esc_attr( $alt_text ) . '" ' . $dimension_text . ' title="' . esc_attr( $alt_text ) . '" />';

          echo '<div class="tpiw-widget-wrapper">';

          echo sprintf( '<div class="tpiw-image" >%s%s%s</div>',
            $instance['link_open'],
            $imgtag,
            $instance['link_close']
          );

         	echo '<div class="tpiw-widget-content">';

	        if ( $title ) {
	        echo $before_title ;

	        if ( $tpiw_disable_link_in_title ) {
	           echo sprintf( '%s', $title );
	        }
	        else{
	           	echo sprintf( '%s%s%s',
	              $instance['link_open'],
	              $title,
	              $instance['link_close']
	            );
	        }
	          	echo $after_title ;
	        }

	        if( ! empty( $subtitle )){
	        	echo sprintf( '<span class="tagline">%s</span>', $subtitle );
	        }

          	if ( ! empty($tpiw_image_caption)) {
                echo sprintf( '<div class="tpiw-image-caption">%s</div>', $tpiw_image_caption );
            }

         	if( ! empty ( $tpiw_link ) ){
         		if ( $tpiw_show_button ) {
              		echo sprintf( '<div class="tpiw-link-button"> %s%s%s</div>',
                		$instance['link_open'],
                		'<input type="button" value="' . esc_attr( $tpiw_button_text ) . '"></button>',
                		$instance['link_close'] );
            	}
          	}
          	echo '</div><!-- .widget-content -->';
        echo '</div><!-- .piw-widget-wrapper -->';

        } // End if : image is there.

		echo $args['after_widget'];
	}

	/**
	 * Back-end widget form.
	 *
	 * @see WP_Widget::form()
	 *
	 * @param array $instance Previously saved values from database.
	 */
	public function form( $instance ) {
		// Defaults.
        $instance = wp_parse_args( (array) $instance, array(
			'title'                      =>  '',
			'subtitle'					 =>  '',
			'tpiw_image_url'             =>  '',
			'tpiw_image_width'           =>  '',
			'tpiw_image_height'          =>  '',
			'tpiw_link'                  =>  '',
			'tpiw_alt_text'              =>  '',
			'tpiw_open_link'             =>  0,
			'tpiw_image_caption'         =>  '',
			'tpiw_disable_link_in_title' =>  0,
			'tpiw_show_button'           =>  0,
			'tpiw_button_text'           => '',
          ) );

		$title                        = htmlspecialchars( $instance['title'] );

		$subtitle					  = isset( $instance['subtitle'] ) ? $instance['subtitle'] : '';

		$tpiw_image_url               = isset( $instance['tpiw_image_url'] ) ? $instance['tpiw_image_url'] : '';

		$tpiw_image_width             = isset( $instance['tpiw_image_width'] ) ? $instance['tpiw_image_width'] : '';

		$tpiw_image_height            = isset( $instance['tpiw_image_height'] ) ? $instance['tpiw_image_height'] : '';
		$tpiw_link                    = isset( $instance['tpiw_link'] ) ? $instance['tpiw_link'] : '';

		$tpiw_alt_text                = isset( $instance['tpiw_alt_text'] ) ? $instance['tpiw_alt_text'] : '';

		$tpiw_open_link               = isset( $instance['tpiw_open_link'] ) ? $instance['tpiw_open_link'] : false;

		$tpiw_image_caption           = isset( $instance['tpiw_image_caption' ] ) ? $instance['tpiw_image_caption'] : '';
		$tpiw_disable_link_in_title   = isset( $instance['tpiw_disable_link_in_title'] ) ? $instance['tpiw_disable_link_in_title'] : false;

		$tpiw_show_button 			  = isset( $instance['tpiw_show_button'] ) ? $instance['tpiw_show_button'] : true;

		$tpiw_button_text			  = isset( $instance['tpiw_button_text'] ) ? $instance['tpiw_button_text'] : '';

		?>
		<p>
		<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php _e( 'Title:', 'flat-commerce' ); ?></label>
		<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ), 'flat-commerce' ); ?>" type="text" value="<?php echo esc_attr( $title, 'flat-commerce' ); ?>">
		</p>

		<p>
		<label for="<?php echo esc_attr( $this->get_field_id( 'subtitle' ) ); ?>"><?php _e( 'Sub Title:', 'flat-commerce' ); ?></label>
		<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'subtitle' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'subtitle' ), 'flat-commerce' ); ?>" type="text" value="<?php echo esc_attr( $subtitle, 'flat-commerce' ); ?>">
		</p>
		<!-- Place holder for image upload -->
		<div>
	      <label for="<?php echo esc_attr( $this->get_field_id( 'tpiw_image_url' ) ); ?>"><?php _e( 'Image URL', 'flat-commerce' ); ?></label>:<br />
	      <input type="text" class="img widefat" name="<?php echo esc_attr( $this->get_field_name( 'tpiw_image_url' ), 'flat-commerce' ); ?>" id="<?php echo esc_attr( $this->get_field_id( 'tpiw_image_url' ) ); ?>" value="<?php echo esc_url( $tpiw_image_url ); ?>" /><br />
	      <input type="button" class="select-img button button-primary" value="<?php _e( 'Upload', 'flat-commerce' ); ?>" data-uploader_title="<?php _e( 'Select Image', 'flat-commerce' ); ?>" data-uploader_button_text="<?php _e( 'Choose Image', 'flat-commerce' ); ?>" style="margin-top:5px;" />

	      <?php
	        $full_image_url = '';
	        if (! empty( $tpiw_image_url ) ){
	          $full_image_url = $tpiw_image_url;
	        }
	        $wrap_style = '';
	        if ( empty( $full_image_url ) ) {
	          $wrap_style = ' style="display:none;" ';
	        }
	      ?>
	      	<div class="tpiw-preview-wrap" <?php echo esc_attr( $wrap_style, 'flat-commerce' ); ?>>
	        	<img src="<?php echo esc_url( $full_image_url ); ?>" alt="<?php _e('Preview', 'flat-commerce'); ?>" style="max-width: 100%;"  />
	      	</div><!-- .tpiw-preview-wrap -->

    	</div>

		<p>
      <label for="<?php echo esc_attr( $this->get_field_id( 'tpiw_image_width' ) ); ?>"><?php _e( 'Image Width', 'flat-commerce' ); ?>:</label>
        <input id="<?php echo esc_attr( $this->get_field_id( 'tpiw_image_width' ) ); ?>"
        name="<?php echo esc_attr( $this->get_field_name( 'tpiw_image_width' ), 'flat-commerce' ); ?>" type="text" value="<?php echo esc_attr( $tpiw_image_width ); ?>" style="max-width:60px;"/>&nbsp;<em class="small"><?php _e( 'in pixel', 'flat-commerce' ); ?></em>
    </p>

    <p>
      <label for="<?php echo esc_attr( $this->get_field_id( 'tpiw_image_height' ) ); ?>"><?php _e( 'Image Height', 'flat-commerce' ); ?>:</label>
        <input id="<?php echo esc_attr( $this->get_field_id( 'tpiw_image_height' ) ); ?>"
        name="<?php echo esc_attr( $this->get_field_name( 'tpiw_image_height' ), 'flat-commerce' ); ?>" type="text" value="<?php echo esc_attr( $tpiw_image_height, 'flat-commerce' ); ?>" style="max-width:60px;"/>&nbsp;<em class="small"><?php _e( 'in pixel', 'flat-commerce' ); ?></em>
    </p>

    <p>
      <label for="<?php echo esc_attr( $this->get_field_id( 'tpiw_alt_text' ) ); ?>"><?php _e( 'Alt Text', 'flat-commerce' ); ?>:</label>
        <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'tpiw_alt_text' ) ); ?>"
        name="<?php echo esc_attr( $this->get_field_name( 'tpiw_alt_text' ), 'flat-commerce' ); ?>" type="text" value="<?php echo esc_attr( $tpiw_alt_text, 'flat-commerce' ); ?>" />
    </p>

    <p>
      <label for="<?php echo esc_attr( $this->get_field_id( 'tpiw_link' ) ); ?>"><?php _e( 'Link', 'flat-commerce' ); ?>:</label>
        <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'tpiw_link' ) ); ?>"
        name="<?php echo esc_attr( $this->get_field_name( 'tpiw_link' ), 'flat-commerce' ); ?>" type="text" value="<?php echo esc_url( $tpiw_link ); ?>" />
    </p>

    <p>
      <label for="<?php echo esc_attr( $this->get_field_id( 's' ) ); ?>"><?php _e( 'Open in New Tab', 'flat-commerce' ); ?>:</label>
      <input id="<?php echo esc_attr( $this->get_field_id( 'tpiw_open_link' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'tpiw_open_link' ), 'flat-commerce' ); ?>" type="checkbox" <?php checked( isset( $instance['tpiw_open_link'] ) ? $instance['tpiw_open_link'] : 0 ); ?> />
    </p>

    <p>
      <label for="<?php echo esc_attr( $this->get_field_id( 'tpiw_disable_link_in_title' ) ); ?>"><?php _e( 'Disable Link in Title', 'flat-commerce' ); ?>:</label>
      <input id="<?php echo esc_attr( $this->get_field_id( 'tpiw_disable_link_in_title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'tpiw_disable_link_in_title' ), 'flat-commerce' ); ?>" type="checkbox" <?php checked( isset( $instance['tpiw_disable_link_in_title'] ) ? $instance['tpiw_disable_link_in_title'] : 0 ); ?> />
    </p>

    <p>
      <label for="<?php echo esc_attr( $this->get_field_id( 'tpiw_show_button' ) ); ?>"><?php _e( 'Show Button', 'flat-commerce' ); ?>:</label>
      <input id="<?php echo esc_attr( $this->get_field_id( 'tpiw_show_button' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'tpiw_show_button' ), 'flat-commerce' ); ?>" type="checkbox" <?php checked( isset( $instance['tpiw_show_button'] ) ? $instance['tpiw_show_button'] : 0 ); ?> />
    </p>
    <!-- 	Button text -->
    <p>
      <label for="<?php echo esc_attr( $this->get_field_id( 'tpiw_button_text' ) ); ?>"><?php _e( 'Button text', 'flat-commerce' ); ?>:</label>
      <input id="<?php echo esc_attr( $this->get_field_id( 'tpiw_button_text' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'tpiw_button_text' ), 'flat-commerce' ); ?>" type="text" value="<?php echo esc_attr( $tpiw_button_text ); ?>">
    </p>

    <p>
      <label for="<?php echo esc_attr( $this->get_field_id( 'tpiw_image_caption' ) ); ?>"><?php _e( 'Caption', 'flat-commerce' ); ?>:</label>
      <textarea class="widefat" rows="2" id="<?php echo esc_attr( $this->get_field_id( 'tpiw_image_caption' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'tpiw_image_caption' ), 'flat-commerce' ); ?>"><?php echo esc_textarea( $tpiw_image_caption ); ?></textarea>
    </p>
		<?php
	}

	/**
	 * Sanitize widget form values as they are saved.
	 *
	 * @see WP_Widget::update()
	 *
	 * @param array $new_instance Values just sent to be saved.
	 * @param array $old_instance Previously saved values from database.
	 *
	 * @return array Updated safe values to be saved.
	 */
	public function update( $new_instance, $old_instance ) {
		$instance                               = $old_instance;

		$instance['title']                      = ( ! empty( $new_instance['title'] ) ) ? strip_tags( stripslashes ( $new_instance['title'] ) ) : '';
		$instance['subtitle']                   = esc_html( $new_instance['subtitle'] );
		$instance['tpiw_image_url']             = esc_url( $new_instance['tpiw_image_url'] );
		$instance['tpiw_image_width']           = esc_attr( $new_instance['tpiw_image_width'] );
		$instance['tpiw_image_height']          = esc_attr( $new_instance['tpiw_image_height'] );
		$instance['tpiw_link']                  = esc_url( $new_instance['tpiw_link'] );
		$instance['tpiw_alt_text']              = esc_attr( $new_instance['tpiw_alt_text'] );
		$instance['tpiw_open_link']             = isset( $new_instance['tpiw_open_link'] );
		$instance['tpiw_disable_link_in_title'] = isset( $new_instance['tpiw_disable_link_in_title'] );
		$instance['tpiw_show_button']           = isset( $new_instance['tpiw_show_button'] );
		$instance['tpiw_image_caption']         = esc_textarea( $new_instance['tpiw_image_caption'] );
		$instance['tpiw_button_text']           = esc_attr( $new_instance['tpiw_button_text'] );

		return $instance;
	}

} // class tp_image_widget
